LANGUAGES = [
    'APL', 'Bash', 'C', 'CSharp', 'Cpp', 'COBOL', 'Lisp',
    'FSharp', 'Fortran', 'Gerbil', 'Go', 'Haskell', 'Java',
    'JavaScript', 'JavaScriptSpiderMonkey', 'Julia', 'Kotlin',
    'ObjectiveC', 'OCaml', 'Pascal', 'PHP', 'Prolog', 'Python2',
    'Python3', 'Ruby', 'Rust', 'TypeScript'
]

COUNTRIES = {
    'AFG': 'Afghanistan',
    'AGO': 'Angola',
    'ALB': 'Albania',
    'AND': 'Andorra',
    'ARE': 'United Arab Emirates',
    'ARG': 'Argentina',
    'ARM': 'Armenia',
    'ATG': 'Antigua and Barbuda',
    'AUS': 'Australia',
    'AUT': 'Austria',
    'AZE': 'Azerbaijan',
    'BDI': 'Burundi',
    'BEL': 'Belgium',
    'BEN': 'Benin',
    'BFA': 'Burkina Faso',
    'BGD': 'Bangladesh',
    'BGR': 'Bulgaria',
    'BHR': 'Bahrain',
    'BHS': 'Bahamas',
    'BIH': 'Bosnia and Herzegovina',
    'BLR': 'Belarus',
    'BLZ': 'Belize',
    'BOL': 'Bolivia',
    'BRA': 'Brazil',
    'BRB': 'Barbados',
    'BRN': 'Brunei',
    'BTN': 'Bhutan',
    'BWA': 'Botswana',
    'CAF': 'Central African Republic',
    'CAN': 'Canada',
    'CHE': 'Switzerland',
    'CHL': 'Chile',
    'CHN': 'China',
    'CIV': 'Ivory Coast',
    'CMR': 'Cameroon',
    'COD': 'Congo-Kinshasa',
    'COG': 'Congo-Brazzaville',
    'COK': 'Cook Islands',
    'COL': 'Colombia',
    'COM': 'Comoros',
    'CPV': 'Cape Verde',
    'CRI': 'Costa Rica',
    'CUB': 'Cuba',
    'CYP': 'Cyprus',
    'CZE': 'Czechia',
    'DEU': 'Germany',
    'DJI': 'Djibouti',
    'DMA': 'Dominica',
    'DNK': 'Denmark',
    'DOM': 'Dominican Republic',
    'DZA': 'Algeria',
    'ECU': 'Ecuador',
    'EGY': 'Egypt',
    'ERI': 'Eritrea',
    'ESH': 'Western Sahara',
    'ESP': 'Spain',
    'EST': 'Estonia',
    'ETH': 'Ethiopia',
    'FIN': 'Finland',
    'FJI': 'Fiji',
    'FRA': 'France',
    'FRO': 'Faroe Islands',
    'FSM': 'Micronesia',
    'GAB': 'Gabon',
    'GBR': 'United Kingdom',
    'GEO': 'Georgia',
    'GHA': 'Ghana',
    'GIN': 'Guinea',
    'GLP': 'Guadeloupe',
    'GMB': 'Gambia',
    'GNB': 'Guinea-Bissau',
    'GNQ': 'Equatorial Guinea',
    'GRC': 'Greece',
    'GRD': 'Grenada',
    'GRL': 'Greenland',
    'GTM': 'Guatemala',
    'GUF': 'French Guiana',
    'GUY': 'Guyana',
    'HKG': 'Hong Kong',
    'HND': 'Honduras',
    'HRV': 'Croatia',
    'HTI': 'Haiti',
    'HUN': 'Hungary',
    'IDN': 'Indonesia',
    'IMN': 'Isle of Man',
    'IND': 'India',
    'IRL': 'Ireland',
    'IRN': 'Iran',
    'IRQ': 'Iraq',
    'ISL': 'Iceland',
    'ISR': 'Israel',
    'ITA': 'Italy',
    'JAM': 'Jamaica',
    'JOR': 'Jordan',
    'JPN': 'Japan',
    'KAZ': 'Kazakhstan',
    'KEN': 'Kenya',
    'KGZ': 'Kyrgyzstan',
    'KHM': 'Cambodia',
    'KIR': 'Kiribati',
    'KNA': 'Saint Kitts and Nevis',
    'KOR': 'South Korea',
    'KWT': 'Kuwait',
    'LAO': 'Laos',
    'LBN': 'Lebanon',
    'LBR': 'Liberia',
    'LBY': 'Libya',
    'LCA': 'Saint Lucia',
    'LIE': 'Liechtenstein',
    'LKA': 'Sri Lanka',
    'LSO': 'Lesotho',
    'LTU': 'Lithuania',
    'LUX': 'Luxembourg',
    'LVA': 'Latvia',
    'MAC': 'Macau',
    'MAR': 'Morocco',
    'MCO': 'Monaco',
    'MDA': 'Moldova',
    'MDG': 'Madagascar',
    'MDV': 'Maldives',
    'MEX': 'Mexico',
    'MHL': 'Marshall Islands',
    'MKD': 'North Macedonia',
    'MLI': 'Mali',
    'MLT': 'Malta',
    'MMR': 'Myanmar',
    'MNE': 'Montenegro',
    'MNG': 'Mongolia',
    'MOZ': 'Mozambique',
    'MRT': 'Mauritania',
    'MTQ': 'Martinique',
    'MUS': 'Mauritius',
    'MWI': 'Malawi',
    'MYS': 'Malaysia',
    'NAM': 'Namibia',
    'NER': 'Niger',
    'NGA': 'Nigeria',
    'NIC': 'Nicaragua',
    'NIU': 'Niue',
    'NLD': 'Netherlands',
    'NOR': 'Norway',
    'NPL': 'Nepal',
    'NRU': 'Nauru',
    'NZL': 'New Zealand',
    'OMN': 'Oman',
    'PAK': 'Pakistan',
    'PAN': 'Panama',
    'PER': 'Peru',
    'PHL': 'Philippines',
    'PLW': 'Palau',
    'PNG': 'Papua New Guinea',
    'POL': 'Poland',
    'PRK': 'North Korea',
    'PRT': 'Portugal',
    'PRY': 'Paraguay',
    'PSE': 'Palestine',
    'QAT': 'Qatar',
    'ROU': 'Romania',
    'RUS': 'Russia',
    'RWA': 'Rwanda',
    'SAU': 'Saudi Arabia',
    'SDN': 'Sudan',
    'SEN': 'Senegal',
    'SGP': 'Singapore',
    'SLB': 'Solomon Islands',
    'SLE': 'Sierra Leone',
    'SLV': 'El Salvador',
    'SMR': 'San Marino',
    'SOM': 'Somalia',
    'SRB': 'Serbia',
    'SSD': 'South Sudan',
    'STP': 'São Tomé and Príncipe',
    'SUR': 'Suriname',
    'SVK': 'Slovakia',
    'SVN': 'Slovenia',
    'SWE': 'Sweden',
    'SWZ': 'Eswatini',
    'SYC': 'Seychelles',
    'SYR': 'Syria',
    'TCD': 'Chad',
    'TGO': 'Togo',
    'THA': 'Thailand',
    'TJK': 'Tajikistan',
    'TKM': 'Turkmenistan',
    'TLS': 'Timor-Leste',
    'TON': 'Tonga',
    'TTO': 'Trinidad and Tobago',
    'TUN': 'Tunisia',
    'TUR': 'Turkey',
    'TUV': 'Tuvalu',
    'TWN': 'Taiwan',
    'TZA': 'Tanzania',
    'UGA': 'Uganda',
    'UKR': 'Ukraine',
    'URY': 'Uruguay',
    'USA': 'United States',
    'UZB': 'Uzbekistan',
    'VAT': 'Vatican City',
    'VCT': 'Saint Vincent and the Grenadines',
    'VEN': 'Venezuela',
    'VNM': 'Vietnam',
    'VUT': 'Vanuatu',
    'WSM': 'Samoa',
    'YEM': 'Yemen',
    'ZAF': 'South Africa',
    'ZMB': 'Zambia',
    'ZWE': 'Zimbabwe'
}

UNIVERSITIES = {
    'aabu.edu.jo': 'Al al-Bayt University',
    'aalto.fi': 'Aalto University',
    'aast.edu': 'Arab Academy for Science & Technology',
    'aau.dk': 'Aalborg University',
    'aau.edu.et': 'Addis Ababa University',
    'abdn.ac.uk': 'University of Aberdeen',
    'aber.ac.uk': 'University of Wales, Aberystwyth',
    'abertay.ac.uk': 'University of Abertay Dundee',
    'abtech.edu': 'Asheville-\u200bBuncombe Technical Community College',
    'acadiau.ca': 'Acadia University',
    'acu.edu': 'Abilene Christian University',
    'ada.edu.az': 'Azerbaijan Diplomatic Academy',
    'adamson.edu.ph': 'Adamson University',
    'addu.edu.ph': 'Ateneo de Davao University',
    'adelaide.edu.au': 'University of Adelaide',
    'adelphi.edu': 'Adelphi University',
    'adnu.edu.ph': 'Ateneo de Naga University',
    'adpu.edu.az': 'Azerbaijan State Pedagogic University',
    'adygnet.ru': 'Adygeja State University',
    'aegean.gr': 'Aegean University',
    'africau.edu': 'Africa University',
    'agh.edu.pl': 'AGH University of Science and Technology',
    'agnesscott.edu': 'Agnes Scott College',
    'agu.edu.tr': 'Abdullah Gul University',
    'ahu.edu.cn': 'Anhui University',
    'ait.ie': 'Athlone Institute of Technology',
    'aiu.edu.sy': 'Arab European University',
    'aiub.edu': 'American International University - Bangladesh',
    'ajou.ac.kr': 'Ajou University',
    'akita-u.ac.jp': 'Akita University',
    'albaath-univ.edu.sy': 'Al-Baath University',
    'albany.edu': 'State University of New York at Albany',
    'albion.edu': 'Albion College',
    'alfaisal.edu': 'Alfaisal University',
    'alma.edu': 'Alma College',
    'alquds.edu': 'Al-Quds University - The Arab University in Jerusalem',
    'american.edu': 'American University',
    'amherst.edu': 'Amherst College',
    'amikom.ac.id': 'STMIK AMIKOM Yogyakarta',
    'amity.edu': 'Amity University',
    'ammanu.edu.jo': 'Al-Ahliyya Amman University',
    'amrita.edu': 'Amrita Vishwa Vidyapeetham (Deemed University)',
    'amu.ac.in': 'Aligarh Muslim University',
    'amu.edu.et': 'Arba Minch University',
    'amu.edu.pl': 'Adam Mickiewicz University of Poznan',
    'amursu.ru': 'Amur State University',
    'anadolu.edu.tr': 'Anadolu University',
    'andong.ac.kr': 'Andong National University',
    'angelo.edu': 'Angelo State University',
    'ankara.edu.tr': 'Ankara University',
    'annauniv.edu': 'Anna University',
    'anselm.edu': 'Saint Anselm College',
    'anu.edu.au': 'Australian National University',
    'aoyama.ac.jp': 'Aoyama Gakuin University',
    'appstate.edu': 'Appalachian State University',
    'apsu.edu': 'Austin Peay State University',
    'apu.edu': 'Azusa Pacific University',
    'aquinas.edu': 'Aquinas College',
    'arabou.edu.sa': 'Arab Open University',
    'araku.ac.ir': 'Arak University',
    'arapahoe.edu': 'Arapahoe Community College',
    'arbor.edu': 'Spring Arbor College',
    'arcadia.edu': 'Arcadia College',
    'ariel.ac.il': 'Ariel University Center of Samaria',
    'arizona.edu': 'University of Arizona',
    'ase.md': 'Academy of Economic Studies of Moldova',
    'ase.ro': 'Academia de Studii Economice din Bucuresti',
    'ashland.edu': 'Ashland University',
    'asoiu.edu.az': 'Azerbaijan State University of Oil and Industry',
    'astate.edu': 'Arkansas State University',
    'aston.ac.uk': 'Aston University',
    'astu.edu.et': 'Adama Science and Technology University',
    'astu.org': 'Astrahan State Technical University',
    'asu.edu': 'Arizona State University',
    'asu.edu.et': 'Assosa University',
    'asu.ru': 'Altai State University',
    'atbu.edu.ng': 'Abubakar Tafawa Balewa University',
    'athabascau.ca': 'Athabasca University',
    'atilim.edu.tr': 'Atilim University',
    'atmajaya.ac.id': 'Universitas Katolik Indonesia Atma Jaya',
    'atu.ac.ir': 'Allameh Tabatabaie University',
    'atu.edu': 'Arkansas Tech University',
    'au.dk': 'Aarhus University',
    'au.edu': 'Assumption University of Thailand',
    'aua.am': 'American University of Armenia',
    'auaf.edu.af': 'American University of Afghanistan',
    'aub.edu.lb': 'American University of Beirut',
    'auburn.edu': 'Auburn University',
    'auca.kg': 'American University of Central Asia',
    'aucegypt.edu': 'American University in Cairo',
    'auckland.ac.nz': 'University of Auckland',
    'aueb.gr': 'Athens University of Economics and Business',
    'auf.edu.ph': 'Angeles University',
    'augie.edu': 'Augustana College (SD)',
    'augsburg.edu': 'Augsburg College',
    'augusta.edu': 'Augusta University',
    'augustana.edu': 'Augustana College (IL)',
    'aui.ma': 'Al Akhawayn University',
    'aul.edu.lb': 'Arts, Sciences and Technology University',
    'aum.edu': 'Auburn University at Montgomery',
    'aun.edu.eg': 'Assiut University',
    'aus.edu': 'American University of Sharjah',
    'aust.edu': 'Ahsanullah University of Science & Technology',
    'austincc.edu': 'Austin Community College',
    'aut.ac.ir': 'Amirkabir University of Technology',
    'aut.ac.nz': 'Auckland University of Technology',
    'auth.gr': 'Aristotle University of Thessaloniki',
    'avc.edu': 'Antelope Valley College',
    'azc.uam.mx': 'Universidad Autónoma Metropolitana - Azcapotzalco',
    'azhar.edu.eg': 'Al Azhar University',
    'aztu.edu.az': 'Azerbaijan Technical University',
    'babson.edu': 'Babson College',
    'baghdadcollege.edu.iq': 'Baghdad College of Economic Sciences University',
    'bahcesehir.edu.tr': 'Bahcesehir University',
    'bahria.edu.pk': 'Bahria University',
    'bakeru.edu': 'Baker University',
    'bakhtar.edu.af': 'Bakhtar University',
    'bakrie.ac.id': 'Universitas Bakrie',
    'bard.edu': 'Bard College',
    'barry.edu': 'Barry University',
    'bashedu.ru': 'Bashkir State Agrarian University',
    'baskent.edu.tr': 'Baskent University',
    'basu.ac.ir': 'Bu Ali Sina University',
    'bath.ac.uk': 'University of Bath',
    'batman.edu.tr': 'Batman University',
    'bau.edu.jo': 'Al-Balqa Applied University',
    'bau.edu.lb': 'Beirut Arab University',
    'baylor.edu': 'Baylor University',
    'bbk.ac.uk': 'Birkbeck College, University of London',
    'bc.edu': 'Boston College',
    'bcit.ca': 'British Columbia Institute of Technology',
    'bdu.edu.et': 'Bahir Dar University',
    'beds.ac.uk': 'University of Bedfordshire',
    'belmont.edu': 'Belmont University',
    'beloit.edu': 'Beloit College',
    'bemidjistate.edu': 'Bemidji State University',
    'benedictine.edu': 'Benedictine College',
    'berea.edu': 'Berea College',
    'berkeley.edu': 'University of California, Berkeley',
    'bethel.edu': 'Bethel University',
    'bethelks.edu': 'Bethel College (KS)',
    'beun.edu.tr': 'Bulent Ecevit University',
    'bfh.ch': 'BFH - Bern University of Applied Sciences',
    'bfsu.edu.cn': 'Beijing Foreign Studies University',
    'bg.ac.rs': 'University of Belgrade',
    'bgsu.edu': 'Bowling Green State University',
    'bgu.ac.il': 'Ben-Gurion University of the Negev',
    'bhsu.edu': 'Black Hills State University',
    'bhu.ac.in': 'Banaras Hindu University',
    'bicol-u.edu.ph': 'Bicol University',
    'bilgi.edu.tr': 'Istanbul Bilgi University',
    'bilkent.edu.tr': 'Bilkent University',
    'binghamton.edu': 'State University of New York at Binghamton',
    'binus.ac.id': 'Binus University',
    'biola.edu': 'Biola University',
    'birjand.ac.ir': 'Birjand University',
    'birzeit.edu': 'Birzeit University',
    'bit.edu.cn': 'Beijing Institute of Technology',
    'bits-pilani.ac.in': 'Birla Institute of Technology and Science',
    'biu.ac.il': 'Bar-Ilan University',
    'biust.ac.bw': 'Botswana International University of Science & Technology',
    'bjfu.edu.cn': 'Beijing Forestry University',
    'bjtu.edu.cn': 'Beijing Jiaotong University',
    'bju.edu': 'Bob Jones University',
    'bme.hu': 'Budapest University of Technology and Economics',
    'bmstu.ru': 'Bauman Moscow State Technical University',
    'bntu.by': 'Belarussian National Technical University',
    'bnu.edu.cn': 'Beijing Normal University',
    'boisestate.edu': 'Boise State University',
    'boku.ac.at': 'Universität für Bodenkultur Wien',
    'bolton.ac.uk': 'University of Bolton',
    'bond.edu.au': 'Bond University',
    'boun.edu.tr': 'Boğaziçi University',
    'bowdoin.edu': 'Bowdoin College',
    'bradley.edu': 'Bradley University',
    'brandeis.edu': 'Brandeis University',
    'brandonu.ca': 'Brandon University',
    'bridgeport.edu': 'University of Bridgeport',
    'bridgewater.edu': 'Bridgewater College',
    'bristol.ac.uk': 'University of Bristol',
    'brockport.edu': 'State University of New York College at Brockport',
    'brocku.ca': 'Brock University',
    'broward.edu': 'Broward College',
    'brown.edu': 'Brown University',
    'brunel.ac.uk': 'Brunel University Uxbridge',
    'brur.ac.bd': 'Begum Rokeya University, Rangpur',
    'brynmawr.edu': 'Bryn Mawr College',
    'bsc.edu': 'Birmingham-Southern College',
    'bseu.by': 'Belarussian State Economic University',
    'bstu.by': 'Brest State Technical University',
    'bstu.ru': 'Belgorod State Technical University',
    'bsu.by': 'Belarussian State University',
    'bsu.edu': 'Ball State University',
    'bsu.edu.az': 'Baku State University',
    'bsu.edu.eg': 'Beni Suef University',
    'bsuir.by': 'Belarussian State University of Informatics and Radioelectronics',
    'bth.se': 'Blekinge Institute of Technology',
    'bu.edu': 'Boston University',
    'bu.edu.bd': 'Bangladesh University',
    'bu.edu.eg': 'Benha University',
    'buaa.edu.cn': 'Beijing University of Aeronautics and Astronautics',
    'buap.mx': 'Benemerita Universidad Autónoma de Puebla',
    'bubt.edu.bd': 'Bangladesh University of Business & Technology',
    'bucknell.edu': 'Bucknell University',
    'buct.edu.cn': 'Beijing University of Chemical Technology',
    'buet.ac.bd': 'Bangladesh University of Engineering and Technology',
    'buffalo.edu': 'State University of New York at Buffalo',
    'bufs.ac.kr': 'Busan University of Foreign Studies',
    'bulsu.edu.ph': 'Bulacan State University',
    'bupt.edu.cn': 'Beijing University of Posts and Telecommunications',
    'butler.edu': 'Butler University',
    'buu.ac.th': 'Burapha University',
    'bvu.edu': 'Buena Vista University',
    'bw.edu': 'Baldwin Wallace University',
    'byu.edu': 'Brigham Young University',
    'byuh.edu': 'Brigham Young University Hawaii',
    'byui.edu': 'Brigham Young University - Idaho',
    'cafa.edu.cn': 'Central Academy of  Fine Art',
    'callutheran.edu': 'California Lutheran University',
    'calpoly.edu': 'California Polytechnic State University, San Luis Obispo',
    'calstatela.edu': 'California State University, Los Angeles',
    'caltech.edu': 'California Institute of Technology',
    'caluniv.ac.in': 'University of Calcutta',
    'calvin.edu': 'Calvin College',
    'cam.ac.uk': 'University of Cambridge',
    'cameron.edu': 'Cameron University',
    'canadacollege.edu': 'Canada College',
    'canisius.edu': 'Canisius College',
    'canterbury.ac.nz': 'University of Canterbury',
    'captechu.edu': 'Capitol Technology University',
    'cardiff.ac.uk': 'Cardiff University',
    'carleton.ca': 'Carleton University',
    'carleton.edu': 'Carleton College',
    'carthage.edu': 'Carthage College',
    'case.edu': 'Case Western Reserve University',
    'caspercollege.edu': 'Casper College',
    'cau.ac.kr': 'Chung-Ang University',
    'cau.edu': 'Clark Atlanta University',
    'cau.edu.cn': 'China Agricultural University',
    'cbs.dk': 'Copenhagen Business School',
    'cbu.edu': 'Christian Brothers University',
    'ccnu.edu.cn': 'Central China Normal University',
    'ccsf.edu': 'City College of San Francisco',
    'ccsu.edu': 'Central Connecticut State University',
    'ccu.edu.tw': 'National Chung Cheng University',
    'ccut.edu.cn': 'Changchun University of Technology',
    'cdu.edu.au': 'Charles Darwin University',
    'cdut.edu.cn': 'Chengdu University of Technology',
    'cedarville.edu': 'Cedarville College',
    'centennialcollege.ca': 'Centennial College',
    'central.edu': 'Central College',
    'centrale-marseille.fr': 'Ecole Centrale de Marseille',
    'centre.edu': 'Centre College',
    'cetys.mx': 'CETYS Universidad',
    'cgu.edu.tw': 'Chang Gung University',
    'chaffey.edu': 'Chaffey College',
    'chalmers.se': 'Chalmers University of Technology',
    'changwon.ac.kr': 'Changwon National University',
    'charusat.ac.in': 'Charotar University of Science and Technology',
    'chattanoogastate.edu': 'Chattanooga State Community College',
    'chester.ac.uk': 'University of Chester',
    'chosun.ac.kr': 'Chosun University',
    'chu.edu.tw': 'Chung Hua University',
    'chubu.ac.jp': 'Chubu University',
    'chuka.ac.ke': 'Chuka University',
    'chula.ac.th': 'Chulalongkorn University',
    'chungbuk.ac.kr': 'Chungbuk National University',
    'chuo-u.ac.jp': 'Chuo University',
    'cihanuniversity.edu.iq': 'Cihan University',
    'cit.ie': 'Cork Institute of Technology',
    'citadel.edu': 'The Citadel',
    'city.ac.uk': 'City University',
    'cityu.edu.hk': 'City University of Hong Kong',
    'cityuniversity.edu.bd': 'City University',
    'clarion.edu': 'Clarion University of Pennsylvania',
    'clarke.edu': 'Clarke College',
    'clarkson.edu': 'Clarkson University',
    'clarku.edu': 'Clark University',
    'clemson.edu': 'Clemson University',
    'clevelandcc.edu': 'Cleveland Community College',
    'cmb.ac.lk': 'University of Colombo',
    'cmc.edu': 'Central Methodist College',
    'cmich.edu': 'Central Michigan University',
    'cmu.edu': 'Carnegie Mellon University',
    'cn.edu': 'Carson-Newman College',
    'cnm.edu': 'Central New Mexico Community College',
    'cnu.ac.kr': 'Chungnam National University',
    'cnu.edu': 'Christopher Newport University',
    'coalrafidain.edu.iq': 'Al Rafidain University College',
    'coastal.edu': 'Coastal Carolina University',
    'cod.edu': 'College of DuPage',
    'coe.edu': 'Coe College',
    'cofc.edu': 'College of Charleston',
    'colby.edu': 'Colby College',
    'colgate.edu': 'Colgate University',
    'collegeofsanmateo.edu': 'College of San Mateo',
    'collegeofthedesert.edu': 'College of the Desert',
    'collin.edu': 'Collin County Community College District',
    'colorado.edu': 'University of Colorado at Boulder',
    'coloradocollege.edu': 'Colorado College',
    'coloradomesa.edu': 'Colorado Mesa University',
    'colostate.edu': 'Colorado State University',
    'columbia.edu': 'Columbia University',
    'columbiastate.edu': 'Columbia State Community College',
    'columbusstate.edu': 'Columbus State University',
    'com.edu': 'College of the Mainland',
    'comu.edu.tr': 'Canakkale (18th March) University',
    'concordia.ca': 'Concordia University',
    'conestogac.on.ca': 'Conestoga College',
    'cooper.edu': 'Cooper Union for the Advancement of Science and Art',
    'cornell.edu': 'Cornell University',
    'cou.ac.bd': 'Comilla University',
    'covenantuniversity.edu.ng': 'Covenant University',
    'coventry.ac.uk': 'Coventry University',
    'cpcc.edu': 'Central Piedmont Community College',
    'cpp.edu': 'California Polytechnic State University, Pomona',
    'cput.ac.za': 'Cape Peninsula University of Technology',
    'cqu.edu.cn': 'Chongqing University',
    'cqupt.edu.cn': 'Chongqing University of Post and Telecommunications',
    'creighton.edu': 'Creighton University',
    'csbsju.edu': "Saint John's University (MN)",
    'csmd.edu': 'College of Southern Maryland',
    'css.edu': 'College of St. Scholastica',
    'csu.edu.cn': 'Central South University',
    'csuchico.edu': 'California State University, Chico',
    'csuci.edu': 'California State University Channel Islands',
    'csudh.edu': 'California State University, Dominguez Hills',
    'csulb.edu': 'California State University, Long Beach',
    'csumb.edu': 'California State University, Monterey Bay',
    'csun.edu': 'California State University, Northridge',
    'csuohio.edu': 'Cleveland State University',
    'csus.edu': 'California State University, Sacramento',
    'csusb.edu': 'California State University, San Bernardino',
    'csusm.edu': 'California State University, San Marcos',
    'ctbu.edu.cn': 'Chongqing Technology and Business University',
    'ctcd.edu': 'Central Texas College',
    'ctu.edu.vn': 'Can-Tho University',
    'cu.ac.bd': 'University of Chittagong',
    'cu.edu.eg': 'Cairo University',
    'cu.edu.tr': 'Cukurova University',
    'cuc.edu.cn': 'Communication University of China',
    'cuea.edu': 'Catholic University of Eastern Africa',
    'cueb.edu.cn': 'Capital University of Economics and Business',
    'cuet.ac.bd': 'Chittagong University of Engineering and Technology',
    'cugb.edu.cn': 'China University of Geoscience Beijing',
    'cujae.edu.cu': 'Instituto Superior Politécnico José Antonio Echeverría',
    'cumt.edu.cn': 'China University of Mining Technology - Xuzhou',
    'cuni.cz': 'Charles University Prague',
    'cuny.edu': 'City University of New York',
    'curtin.edu.au': 'Curtin University of Technology',
    'cusat.ac.in': 'Cochin University of Science and Technology',
    'cust.edu.cn': 'Changchun University of Science and Technology',
    'cut.ac.za': 'Central University of Technology',
    'cut.ac.zw': 'Chinhoyi University of Technology',
    'cvut.cz': 'Czech Technical University of Prague',
    'cycu.edu.tw': 'Chung Yuan Christian University',
    'czu.cz': 'Czech University of Agriculture Prague',
    'daffodilvarsity.edu.bd': 'Daffodil International University',
    'dal.ca': 'Dalhousie University',
    'dartmouth.edu': 'Dartmouth College',
    'davidson.edu': 'Davidson College',
    'dawat.edu.af': 'Dawat University',
    'daystar.ac.ke': 'Daystar University',
    'dbu.edu.et': 'Debre Birhan University',
    'dcu.ie': 'Dublin City University',
    'ddu.ac.in': 'Dharamsinh Desai University',
    'deakin.edu.au': 'Deakin University',
    'deanza.edu': 'De Anza College',
    'delta.edu': 'Delta College',
    'deltastate.edu': 'Delta State University',
    'denison.edu': 'Denison University',
    'depaul.edu': 'DePaul University',
    'depauw.edu': 'DePauw University',
    'deu.ac.kr': 'Dong-Eui University',
    'deu.edu.tr': 'Dokuz Eylül University',
    'devry.edu': 'DeVry Institute of Technology',
    'dgu.ru': 'Dagestan State University',
    'dhbw.de': 'Duale Hochschule Baden-Württemberg',
    'dhu.edu.cn': 'Donghua University, Shanghai',
    'dia.edu.az': 'The Academy of Public Administration',
    'dickinson.edu': 'Dickinson College',
    'digipen.edu': 'DigiPen Institute of Technology',
    'dinus.ac.id': 'Universitas Dian Nuswantoro',
    'dit.ie': 'Dublin Institute of Technology',
    'dkut.ac.ke': 'Dedan Kimathi University of Technology',
    'dlmu.edu.cn': 'Dalian Martime University',
    'dlsu.edu.ph': 'De La Salle University',
    'dlu.edu.cn': 'Dalian University',
    'dlut.edu.cn': 'Dalian University of Technology',
    'dmacc.edu': 'Des Moines Area Community College',
    'dmu.edu.et': 'Debre Markos University',
    'dnu.dp.ua': 'Dnepropetrovsk National University',
    'dnue.ac.kr': 'Daegu National University of Education',
    'dominican.edu': 'Dominican College',
    'donga.ac.kr': 'Dong-A University',
    'dongduk.ac.kr': "Dongduk Women's University",
    'dongguk.edu': 'Dongguk University',
    'dongseo.ac.kr': 'Dongseo University',
    'donntu.edu.ua': 'Donetsk National Technical University',
    'donnu.edu.ua': 'Donetsk National University',
    'dordt.edu': 'Dordt College',
    'doshisha.ac.jp': 'Doshisha University',
    'drake.edu': 'Drake University',
    'drexel.edu': 'Drexel University',
    'drury.edu': 'Drury College',
    'dsu.edu': 'Dakota State University',
    'dtu.dk': 'Technical University of Denmark',
    'du.ac.bd': 'University of Dhaka',
    'du.ac.in': 'University of Delhi',
    'du.ac.ir': 'Damghan University',
    'du.edu': 'University of Denver',
    'du.se': 'Dalarna University College',
    'duc.edu.iq': 'Dijla University College',
    'duet.ac.bd': 'Dhaka University of Engineering and Technology',
    'duke.edu': 'Duke University',
    'dundee.ac.uk': 'University of Dundee',
    'duq.edu': 'Duquesne University',
    'dur.ac.uk': 'University of Durham',
    'dut.ac.za': 'Durban University of Technology',
    'dvc.edu': 'Diablo Valley College',
    'dvgups.ru': 'Far East State Transport University',
    'dyu.ac.kr': 'Dongyang University',
    'eafit.edu.co': 'Universidad EAFIT',
    'eap.gr': 'Hellenic Open University',
    'eastdelta.edu.bd': 'East Delta University',
    'easternuni.edu.bd': 'Eastern University',
    'ec-lille.fr': 'Ecole Centrale de Lille',
    'ec-lyon.fr': 'Ecole Centrale de Lyon',
    'ec-nantes.fr': 'Ecole Centrale de Nantes',
    'ecci.edu.co': 'Escuela Colombiana de Carreras Industriales',
    'ecjtu.jx.cn': 'East China Jiao Tong University',
    'ecnu.edu.cn': 'East China Normal University',
    'ecok.edu': 'East Central University',
    'ecu.edu': 'East Carolina University',
    'ecu.edu.au': 'Edith Cowan University',
    'ecust.edu.cn': 'East China University of Science and Technology',
    'ed.ac.uk': 'University of Edinburgh',
    'edinboro.edu': 'Edinboro University of Pennsylvania',
    'efrei.fr': "Ecole Française d'Electronique et d'Informatique",
    'ege.edu.tr': 'Ege University',
    'egerton.ac.ke': 'Egerton University',
    'ehc.edu': 'Emory & Henry College',
    'ehime-u.ac.jp': 'Ehime University',
    'ehu.eus': 'Universidad del País Vasco',
    'eiu.edu': 'Eastern Illinois University',
    'ektu.kz': 'East Kazakstan State Technical University',
    'eku.edu': 'Eastern Kentucky University',
    'elcamino.edu': 'El Camino Community College District',
    'elon.edu': 'Elon College',
    'elte.hu': 'Eötvös Lorand University',
    'eltech.ru': 'St. Petersburg State Electrotechnical University',
    'emi.ac.ma': "Ecole Mohammadia d'Ingénieurs",
    'emi.edu.bo': 'Escuela Militar de Ingeniería',
    'emich.edu': 'Eastern Michigan University',
    'emory.edu': 'Emory University',
    'emporia.edu': 'Emporia State University',
    'emu.edu': 'Eastern Mennonite University',
    'ens-cachan.fr': 'Ecole Normale Supérieure de Cachan',
    'ens-lyon.fr': 'Ecole Normale Supérieure de Lyon',
    'ens.fr': 'Ecole Normale Supérieure de Paris',
    'ensae.fr': "Ecole Nationale de la Statistique et de l'Administration "
                'Economique',
    'enu.kz': 'L.N. Gumilyov Eurasian National University',
    'epfl.ch': 'EPFL - EPF Lausanne',
    'epita.fr': "Ecole Pour l'Informatique et les Techniques Avancees",
    'epitech.eu': "Ecole pour l'Informatique et les nouvelles Technologies",
    'epoka.edu.al': 'Epoka University',
    'erau.edu': 'Embry-Riddle Aeronautical University',
    'escuelaing.edu.co': 'Escuela Colombiana de Ingeniería Julio Garavito',
    'esiee.fr': "Ecole Supérieure d'Ingénieurs en Electronique et "
                'Electrotechnique',
    'esigelec.fr': "Ecole Supérieure d'Ingénieurs en Génie Electrique",
    'espol.edu.ec': 'Escuela Superior Politécnica del Litoral',
    'essex.ac.uk': 'University of Essex',
    'esstu.ru': 'East-Siberian State University of Technology',
    'ethz.ch': 'ETHZ - ETH Zurich',
    'etown.edu': 'Elizabethtown College',
    'etsu.edu': 'East Tennessee State University',
    'etu.edu.tr': 'Tobb Economics and Technology University',
    'euba.sk': 'University of Economics in Bratislava',
    'eur.nl': 'Erasmus University Rotterdam',
    'evansville.edu': 'University of Evansville',
    'ewha.ac.kr': "Ewha Women's University",
    'ewu.edu': 'Eastern Washington University',
    'ewubd.edu': 'East West University',
    'famu.edu': 'Florida Agricultural and Mechanical University',
    'fandm.edu': 'Franklin and Marshall College',
    'fanshawec.ca': 'Fanshawe College',
    'fatima.edu.ph': 'Our Lady of Fatima University',
    'fau.edu': 'Florida Atlantic University',
    'fcu.edu.tw': 'Feng Chia University',
    'ferris.edu': 'Ferris State University',
    'fh-bielefeld.de': 'Fachhochschule Bielefeld',
    'fh-luebeck.de': 'Fachhochschule Lübeck',
    'fhdw.de': 'Fachhochschule der Wirtschaft',
    'fhnw.ch': 'FHNW - Fachhochschule Nordwestschweiz',
    'fit.edu': 'Florida Institute of Technology',
    'fiu.edu': 'Florida International University',
    'fjnu.edu.cn': 'Fujian Normal University',
    'flinders.edu.au': 'Flinders University of South Australia',
    'fom.de': 'Fachhochschule für Oekonomie und Management (FOM)',
    'fontys.edu': 'Fontys University of Applied Sciences',
    'foothill.edu': 'Foothill College',
    'fordham.edu': 'Fordham University',
    'fortlewis.edu': 'Fort Lewis College',
    'fosu.edu.cn': 'Foshan University',
    'fpt.edu.vn': 'FPT University',
    'fredonia.edu': 'State University of New York at Fredonia',
    'freeuni.edu.ge': 'Free University of Tbilisi',
    'fresnostate.edu': 'California State University, Fresno',
    'frontrange.edu': 'Front Range Community College',
    'frostburg.edu': 'Frostburg State University',
    'fsu.edu': 'Florida State University',
    'ftu.edu.vn': 'Foreign Trade University',
    'fu-berlin.de': 'Freie Universität Berlin',
    'fudan.edu.cn': 'Fudan University',
    'fukuoka-u.ac.jp': 'Fukuoka University',
    'fukushima-u.ac.jp': 'Fukushima University',
    'fullerton.edu': 'California State University, Fullerton',
    'fullsail.edu': 'Full Sail University',
    'furg.br': 'Universidade Federal do Rio Grande',
    'futa.edu.ng': 'Federal University of Technology, Akure',
    'futminna.edu.ng': 'Federal University of Technology, Minna',
    'futo.edu.ng': 'Federal University of Technology, Owerri',
    'fzu.edu.cn': 'Fuzhou University',
    'gachon.ac.kr': 'Gachon University',
    'galileo.edu': 'Universidad Galileo',
    'gatech.edu': 'Georgia Institute of Technology',
    'gazi.edu.tr': 'Gazi University Ankara',
    'gbc.edu': 'Goldey-Beacom College',
    'gbpuat.ac.in': 'Govind Ballabh Pant University of Agriculture and Technology',
    'gcsu.edu': 'Georgia College',
    'gcu.edu': 'Grand Canyon University',
    'gdufs.edu.cn': 'Guangdong University of Foreign Studies',
    'gdut.edu.cn': 'Guangdong University of Technology',
    'geneseo.edu': 'State University of New York College at Geneseo',
    'georgetown.edu': 'Georgetown University',
    'georgiasouthern.edu': 'Georgia Southern University',
    'gettysburg.edu': 'Gettysburg College',
    'ggc.edu': 'Georgia Gwinnett College',
    'ggu.ac.in': 'Guru Ghasidas University',
    'giki.edu.pk': 'Ghulam Ishaq Khan Institute of Science & Technology',
    'gitam.edu': 'Gandhi Institute of Technology and Managment',
    'gju.edu.jo': 'German Jordanian University',
    'gla.ac.uk': 'University of Glasgow',
    'gmu.edu': 'George Mason University',
    'gonzaga.edu': 'Gonzaga University',
    'goshen.edu': 'Goshen College',
    'goucher.edu': 'Goucher College',
    'govst.edu': 'Governors State University',
    'graceland.edu': 'Graceland College',
    'gre.ac.uk': 'University of Greenwich',
    'green.edu.bd': 'Green University of Bangladesh',
    'grenoble-inp.fr': 'Institut polytechnique de Grenoble',
    'griffith.edu.au': 'Griffith University',
    'grinnell.edu': 'Grinnell College',
    'grsu.by': 'Grodno State University Yanka Kupaly',
    'gsu.edu': 'Georgia State University',
    'gtu.ac.in': 'Gujarat Technological University Ahmedabad',
    'gtu.edu.tr': 'Gebze Tecnical University',
    'gu.se': 'Göteborg University',
    'guc.edu.eg': 'German University in Cairo',
    'guilan.ac.ir': 'University of Guilan',
    'gunadarma.ac.id': 'Universitas Gunadarma',
    'gvsu.edu': 'Grand Valley State University',
    'gwnu.ac.kr': 'Gangneung-Wonju National University',
    'gwu.edu': 'George Washington University',
    'gzhu.edu.cn': 'Guangzhou University',
    'h-brs.de': 'Hochschule Bonn-Rhein-Sieg',
    'hacettepe.edu.tr': 'Hacettepe University',
    'haifa.ac.il': 'University of Haifa',
    'halla.ac.kr': 'Halla University',
    'hamilton.edu': 'Hamilton College',
    'hamptonu.edu': 'Hampton University',
    'hanbat.ac.kr': 'Hanbat National University',
    'hancockcollege.edu': 'Allan Hancock College',
    'handong.edu': 'Handong Global University',
    'hansung.ac.kr': 'Hansung University Seoul',
    'hanyang.ac.kr': 'Hanyang University',
    'haramaya.edu.et': 'Haramaya University',
    'harding.edu': 'Harding University',
    'hartford.edu': 'University of Hartford',
    'hartnell.edu': 'Hartnell College',
    'harvard.edu': 'Harvard University',
    'hau.edu.vn': 'Hanoi University of Architecture',
    'haverford.edu': 'Haverford College in Pennsylvania',
    'hb.se': 'University College of Borås',
    'hbu.edu.cn': 'Hebei University',
    'hcc.edu': 'Holyoke Community College',
    'hcmussh.edu.vn': 'Ho Chi Minh City University of Social Sciences and '
                    'Humanities',
    'hcmut.edu.vn': 'Ho Chi Minh City University of Technology',
    'hcmute.edu.vn': 'University of Technical Education Ho Chi Minh City',
    'hebut.edu.cn': 'Hebei University of Technology',
    'hec.edu': 'École des Hautes Études Commerciales (HEC Business School)',
    'heidelberg.edu': 'Heidelberg College',
    'helsinki.fi': 'University of Helsinki',
    'helwan.edu.eg': 'Helwan University',
    'henau.edu.cn': 'Henan Agriculture University',
    'hendrix.edu': 'Hendrix College',
    'henu.edu.cn': 'Henan Univeristy',
    'herts.ac.uk': 'University of Hertfordshire',
    'hfut.edu.cn': 'Hefei University of Technology',
    'hh.se': 'Halmstad University College',
    'hhs.se': 'Stockholm School of Economics',
    'hhu.edu.cn': 'Hehai University',
    'hi.is': 'University of Iceland',
    'hig.se': 'University College of Gävle',
    'highpoint.edu': 'High Point University',
    'hilo.hawaii.edu': 'University of Hawaii at Hilo',
    'himolde.no': 'Molde University College',
    'hiram.edu': 'Hiram College',
    'hiroshima-u.ac.jp': 'Hiroshima University',
    'his.se': 'University College of Skövde',
    'hit.ac.zw': 'Harare Institute of Technology',
    'hit.edu.cn': 'Harbin Institute of Technology',
    'hkbu.edu.hk': 'Hong Kong Baptist University',
    'hkr.se': 'University College of Kristianstad',
    'hku.hk': 'University of Hong Kong',
    'hlju.edu.cn': 'Heilongjiang University',
    'hm.edu': 'Hochschule München',
    'hmc.edu': 'Harvey Mudd College',
    'hmu.edu.vn': 'Hanoi Medical University',
    'hnu.edu.cn': 'Hunan University',
    'hofstra.edu': 'Hofstra University',
    'hokudai.ac.jp': 'Hokkaido University',
    'holycross.edu': 'College of the Holy Cross',
    'hongik.ac.kr': 'Hongik University',
    'hood.edu': 'Hood College',
    'hope.edu': 'Hope College',
    'hosei.ac.jp': 'Hosei University',
    'hoseo.ac.kr': 'Hoseo University',
    'hou.edu.vn': 'Hanoi Open University',
    'howard.edu': 'Howard University',
    'howest.be': 'Hogeschool West-Vlaanderen (TU)',
    'hpu.edu': 'Hawaii Pacific University',
    'hqu.edu.cn': 'Huaqiao University Quanzhuo',
    'hrbeu.edu.cn': 'Harbin Engineering University',
    'hrbnu.edu.cn': 'Harbin Normal University',
    'hrbust.edu.cn': 'Harbin University of Science and Technology',
    'hs-hannover.de': 'Hochschule Hannover',
    'hs-ulm.de': 'Hochschule Ulm, Hochschule für Angewandte Wissenschaft',
    'hse.ru': 'Higher School of Economics',
    'hsleiden.nl': 'Hogeschool Leiden',
    'hstu.ac.bd': 'Hajee Mohammad Danesh Science and Technology University',
    'hti.edu.eg': 'Higher Technological Institute',
    'htu.edu': 'Huston-Tillotson University',
    'hu-berlin.de': 'Humboldt Universität Berlin',
    'hu.edu.et': 'Hawassa University',
    'hu.edu.jo': 'Hashemite University',
    'hu.nl': 'Hogeschool Utrecht',
    'hubu.edu.cn': 'Hubei University',
    'hufs.ac.kr': 'Hankuk University of Foreign Studies',
    'huji.ac.il': 'Hebrew University of Jerusalem',
    'hull.ac.uk': 'University of Hull',
    'humber.ca': 'Humber College',
    'humboldt.edu': 'Humboldt State University',
    'hunnu.edu.cn': 'Hunan Normal University',
    'hust.edu.cn': 'Huazhong University of Science and Technology',
    'hust.edu.vn': 'Hanoi University of Science and Technology',
    'hvcc.edu': 'Hudson Valley Community College',
    'hvtc.edu.vn': 'Institute of Finance',
    'hw.ac.uk': 'Heriot-Watt University',
    'hws.edu': 'Hobart and William Smith Colleges',
    'hzau.edu.cn': 'Huazhong Agricultural University',
    'iastate.edu': 'Iowa State University',
    'iba-suk.edu.pk': 'Institute of Business Administration Sukkur',
    'iba.edu.pk': 'Institute of Business Administration (IBA)',
    'ibaisuniv.edu.bd': 'IBAIS University',
    'ibsu.edu.ge': 'International Blacksea University',
    'icesi.edu.co': 'Universidad ICESI',
    'ieu.edu.tr': 'Izmir University of Economics',
    'ifheindia.org': 'ICFAI University, Hyderabad',
    'ifmo.ru': 'ITMO University',
    'ignou.ac.in': 'Indira Gandhi National Open University',
    'iiit-bh.ac.in': 'International Institute of Information Technology, '
                    'Bhubaneswar',
    'iiitb.ac.in': 'International Institute of Information Technology, Bangalore',
    'iiitd.ac.in': 'Indraprastha Institute of Information Technology, Delhi',
    'iiitm.ac.in': 'Indian Institute of Information Technology and Management - '
                'Gwalior',
    'iiitmk.ac.in': 'Indian Institute of Information Technology and Management - '
                    'Kerala',
    'iiitvadodara.ac.in': 'Indian Institute of Information Technology, Vadodara',
    'iisc.ac.in': 'Indian Institute of Science',
    'iit.edu': 'Illinois Institute of Technology',
    'iitb.ac.in': 'Indian Institute of Technology, Bombay',
    'iitbbs.ac.in': 'IIT Bhubaneswar',
    'iitd.ernet.in': 'Indian Institute of Technology, Delhi',
    'iitg.ac.in': 'Indian Institute of Technology, Guwahati',
    'iith.ac.in': 'Indian Institute of Technology, Hyderabad',
    'iiti.ac.in': 'Indian Institute of Technology, Indore',
    'iitj.ac.in': 'Indian Institute of Technology, Jodhpur',
    'iitk.ac.in': 'Indian Institute of Technology, Kanpur',
    'iitm.ac.in': 'Indian Institute of Technology, Madras',
    'iitp.ac.in': 'Indian Institute of Technology, Patna',
    'iiu.edu.pk': 'International Islamic University',
    'iiuc.ac.bd': 'International Islamic University Chittagong',
    'ikiu.ac.ir': 'Imam Khomeini International University',
    'illinois.edu': 'University of Illinois at Urbana-Champaign',
    'illinoisstate.edu': 'Illinois State University',
    'imau.edu.cn': 'Inner Mongolia Agricultural University',
    'imnu.edu.cn': 'Inner Mongolia Normal University',
    'impa.br': 'Instituto Nacional de Matemática Pura e Aplicada - IMPA',
    'imperial.ac.uk': 'Imperial College London',
    'imtlucca.it': 'Institute for Advanced Studies Lucca',
    'imu.edu.cn': 'Inner Mongolia University',
    'indiana.edu': 'Indiana University at Bloomington',
    'indianatech.edu': 'Indiana Institute of Technology',
    'indstate.edu': 'Indiana State University',
    'indusuni.ac.in': 'Indus University',
    'infnet.edu.br': 'Instituto Infnet',
    'inha.ac.kr': 'Inha University',
    'inholland.nl': 'Hogeschool Inholland',
    'inje.ac.kr': 'Inje University',
    'inpt.ac.ma': 'Institut National des Postes et Télécommunications',
    'insa-lyon.fr': 'Institut National des Sciences Appliquées de Lyon',
    'insa-rennes.fr': 'Institut National des Sciences Appliquées de Rennes',
    'insa-rouen.fr': 'Institut National des Sciences Appliquées de Rouen',
    'intec.edu.do': 'Instituto Tecnológico de Santo Domingo',
    'inter.edu': 'Universidad Interamericana de Puerto Rico',
    'iona.edu': 'Iona College',
    'ipb.ac.id': 'Bogor Agricultural University',
    'ipc.pt': 'Instituto Politécnico de Coimbra',
    'ipfw.edu': 'Indiana University/Purdue University at Fort Wayne',
    'ipp.pt': 'Instituto Politecnico do Porto',
    'ipu.ac.in': 'Guru Gobind Singh Indraprastha University',
    'iscte-iul.pt': 'ISCTE - Instituto Universitário de Lisboa',
    'isep.fr': "Institut Supérieure d'Electronique de Paris",
    'isical.ac.in': 'Indian Statistical Institute',
    'ismdhanbad.ac.in': 'Indian School of Mines (ISM)',
    'ispu.ru': 'Ivanovo State Power University',
    'istanbul.edu.tr': 'Istanbul University',
    'istu.ru': 'Izhevsk State Technical University',
    'isu.edu': 'Idaho State University',
    'isu.edu.tw': 'I-Shou University',
    'isu.ru': 'Irkutsk State University',
    'it-chiba.ac.jp': 'Chiba Institute of Technology',
    'ita.br': 'Instituto Tecnológico de Aeronáutica',
    'ita.mx': 'Instituto Tecnológico de Aguascalientes',
    'itam.mx': 'Instituto Tecnológico Autonómo de México',
    'itb.ac.id': 'Institut Teknologi Bandung',
    'itba.edu.ar': 'Instituto Tecnológico de Buenos Aires',
    'iteso.mx': 'Instituto Tecnológico y de Estudios Superiores de Occidente',
    'itmina.edu.mx': 'Instituto Tecnologico de Minatitlan',
    'itq.edu.mx': 'Instituto Tecnológico de Querétaro',
    'its.ac.id': 'Institut Teknologi Sepuluh Nopember',
    'ittralee.ie': 'Institue of Technology, Tralee',
    'itu.dk': 'IT University of Copenhagen',
    'itu.edu.tr': 'Istanbul Technical University',
    'iu.ac.bd': 'Islamic University Kushtia',
    'iub.edu.bd': 'Independent University, Bangladesh',
    'iubat.edu': 'International University of Business Agriculture and Technology',
    'iugaza.edu.ps': 'Islamic University of Gaza',
    'iup.edu': 'Indiana University of Pennsylvania',
    'iupui.edu': 'Indiana University/Purdue University at Indianapolis',
    'ius.edu': 'Indiana University Southeast',
    'iusb.edu': 'Indiana University at South Bend',
    'iust.ac.ir': 'Iran University of Science and Technology Tehran',
    'iut.ac.ir': 'Isfahan University of Technology',
    'iutoic-dhaka.edu': 'Islamic University of Technology',
    'ivanovo.ac.ru': 'Ivanovo State University',
    'ivc.edu': 'Irvine Valley College',
    'ivytech.edu': 'Ivy Tech Community College',
    'iwate-pu.ac.jp': 'Iwate Prefectural University',
    'iwu.edu': 'Illinois Wesleyan University',
    'iyte.edu.tr': 'Izmir Institute of Technology',
    'jacobs-university.de': 'Jacobs University Bremen',
    'jamiahamdard.edu': 'Jamia Hamdard University',
    'javeriana.edu.co': 'Pontificia Universidad Javeriana',
    'jbu.edu': 'John Brown University',
    'jccc.edu': 'Johnson County Community College',
    'jcu.cz': 'University of South Bohemia',
    'jejunu.ac.kr': 'Jeju National University',
    'jhu.edu': 'Johns Hopkins University',
    'jiit.ac.in': 'Jaypee Institute of Information Technology',
    'jinnah.edu': 'Mohammad Ali Jinnah University, Karachi',
    'jkkniu.edu.bd': 'Jatiya Kabi Kazi Nazrul Islam University',
    'jkuat.ac.ke': 'Jomo Kenyatta University of Agriculture and Technology',
    'jlau.edu.cn': 'Jilin Agricultural University',
    'jlu.edu.cn': 'Jilin University',
    'jmu.edu': 'James Madison University',
    'jmu.edu.cn': 'Jimei University',
    'jnu.ac.bd': 'Jagannath University',
    'jnu.ac.kr': 'Chonnam National University',
    'jnu.edu.cn': 'Jinan University',
    'jnujaipur.ac.in': 'Jaipur National University',
    'jsu.edu.cn': 'Jishou University',
    'jsums.edu': 'Jackson State University',
    'ju.edu': 'Jacksonville University',
    'ju.edu.et': 'Jimma University',
    'ju.edu.jo': 'University of Jordan',
    'ju.edu.sa': 'Aljouf University',
    'juniata.edu': 'Juniata College',
    'juniv.edu': 'Jahangirnagar University',
    'just.edu.jo': 'Jordan University of Science and Technology',
    'jxnu.edu.cn': 'Jiangxi Normal University',
    'jxufe.edu.cn': 'Jiangxi University of Finance and Economics',
    'jyu.fi': 'University of Jyväskylä',
    'kabarak.ac.ke': 'Kabarak University',
    'kagawa-u.ac.jp': 'Kagawa University',
    'kai.ru': 'Kazan State University of Technology',
    'kaist.edu': 'Korea Advanced Institute of Science & Technology',
    'kanagawa-u.ac.jp': 'Kanagawa University',
    'kanazawa-it.ac.jp': 'Kanazawa Institute of Technology',
    'kanazawa-u.ac.jp': 'Kanazawa University',
    'kanchiuniv.ac.in': 'Sri Chandrasekharendra Saraswathi Viswa Mahavidyalaya',
    'kangwon.ac.kr': 'Kangwon National University',
    'kanpuruniversity.org': 'Chhatrapati Shahu Ji Maharaj University',
    'kansai-u.ac.jp': 'Kansai University',
    'kantiana.ru': 'Immanuel Kant State University of Russia',
    'kardan.edu.af': 'Kardan University',
    'karunya.edu': 'Karunya Institute Of Technology ( Deemed University)',
    'karwan.edu.af': 'Karwan Institute of Higher Education',
    'kashanu.ac.ir': 'Kashan University',
    'kateb.edu.af': 'Kateb Institute of Higher Education',
    'kau.edu.sa': 'King Abdul Aziz University',
    'kau.kz': 'Kazak American University',
    'kau.se': 'Karlstad University',
    'kaust.edu.sa': 'King Abdullah University of Science and Technology',
    'kaznu.kz': 'Al-Farabi Kazakh National University',
    'kbsu.ru': 'Kabardino-Balkarian State University',
    'kbtu.kz': 'Kazakh British Technical University',
    'kcl.ac.uk': "King's College London, University of London",
    'kean.edu': 'Kean College',
    'keele.ac.uk': 'Keele University',
    'keio.ac.jp': 'Keio University',
    'keiseruniversity.edu': 'Keiser University',
    'kemsu.ru': 'Kemerovo State University',
    'kennesaw.edu': 'Kennesaw State University',
    'kent.edu': 'Kent State University',
    'kenyon.edu': 'Kenyon College',
    'keralauniversity.ac.in': 'University of Kerala',
    'kfupm.edu.sa': 'King Fahad University of Petroleum and Minerals',
    'khai.edu': 'National Aerospace University Kharkov Aviation Institute',
    'ki.se': 'Karolinska Institute Stockholm',
    'kings.edu': "King's College",
    'kingston.ac.uk': 'Kingston University',
    'kisiiuniversity.ac.ke': 'Kisii University',
    'kit.ac.jp': 'Kyoto Institute of Technology',
    'kit.edu': 'Karlsruher Institut für Technologie',
    'kiu.edu.pk': 'Karakoram International University',
    'kku.ac.th': 'Khon Kaen University',
    'kln.ac.lk': 'Postgraduate Institute of Pali & Buddhist Studies (University '
                'of Kelaniya)',
    'kmitl.ac.th': "King Mongkut's Institute of Technology Ladkrabang",
    'kmu.ac.kr': 'Keimyung University',
    'kmutnb.ac.th': "King Mongkut's University of Technology North Bangkok",
    'knastu.ru': 'Komsomolsk-on-Amur State Technical University',
    'knox.edu': 'Knox College',
    'kntu.ac.ir': 'Khajeh Nasir Toosi University of Technology',
    'knust.edu.gh': 'Kwame Nkrumah University of Science and Technology',
    'kobe-u.ac.jp': 'Kobe University',
    'konkuk.ac.kr': 'Konkuk University',
    'kookmin.ac.kr': 'Kookmin University',
    'koreatech.ac.kr': 'Korea University of Technology and Education',
    'koyauniversity.org': 'Koya University (Kurdistan Region)',
    'kpi.kharkov.ua': 'National Technical University (Kharkiv Polytechnical '
                    'Institute)',
    'kpi.ua': 'National Technical University (Kiev Politechnical Institute)',
    'kpu.ac.kr': 'Korea Polytechnic University',
    'krsu.edu.kg': 'Kyrgyz Russian Slavic University',
    'ks.ac.kr': 'Kyungsung University',
    'kstu.kg': 'Kyrgyz State Technical University',
    'kstu.kz': 'Karaganda State Technical University',
    'ksu.kz': 'Karaganda State Buketov University',
    'ksucta.kg': 'Kyrgyz State University of Construction, Transportation and '
                'Architecture',
    'kth.se': 'KTH Royal Institute of Technology',
    'ku.ac.bd': 'Khulna University',
    'ku.ac.ke': 'Kenyatta University',
    'ku.ac.th': 'Kasetsart University',
    'ku.dk': 'Copenhagen University',
    'ku.edu': 'University of Kansas',
    'ku.edu.af': 'Kabul University',
    'ku.edu.tr': 'Koç University',
    'ku.lt': 'Klaipeda University',
    'kubstu.ru': 'Kuban State University of Technology',
    'kubsu.ru': 'Kuban State University',
    'kud.ac.in': 'Karnatak University',
    'kuet.ac.bd': 'Khulna University of Engineering And Technology',
    'kumamoto-u.ac.jp': 'Kumamoto University',
    'kusa.ac.jp': 'Kurashiki University of Science and the Arts',
    'kustar.ac.ae': 'Khalifa University',
    'kutztown.edu': 'Kutztown University of Pennsylvania',
    'kw.ac.kr': 'Kwangwoon University',
    'kwansei.ac.jp': 'Kwansei Gakuin University',
    'kyonggi.ac.kr': 'Kyonggi University',
    'kyoto-su.ac.jp': 'Kyoto Sangyo University',
    'kyoto-u.ac.jp': 'Kyoto University',
    'kyu.ac.ug': 'Kyambogo University',
    'kyushu-u.ac.jp': 'Kyushu University',
    'kyutech.ac.jp': 'Kyushu Institute of Technology',
    'kzoo.edu': 'Kalamazoo College',
    'labette.edu': 'Labette Community College',
    'lafayette.edu': 'Lafayette College',
    'laikipia.ac.ke': 'Laikipia University',
    'lakeheadu.ca': 'Lakehead University',
    'lamar.edu': 'Lamar University',
    'lander.edu': 'Lander University',
    'lanecc.edu': 'Lane Community College',
    'langara.ca': 'Langara College',
    'lasalle.edu': 'LaSalle University',
    'latech.edu': 'Louisiana Tech University',
    'latrobe.edu.au': 'La Trobe University',
    'lau.edu.lb': 'Lebanese American University',
    'lautech.edu.ng': 'Ladoke Akintola University of Technology',
    'lawrence.edu': 'Lawrence University',
    'lboro.ac.uk': 'Loughborough University',
    'lcc.edu': 'Lansing Community College',
    'lclark.edu': 'Lewis & Clark College',
    'lcu.edu.ng': 'Lead City University of Ibadan',
    'le.ac.uk': 'University of Leicester',
    'leeds.ac.uk': 'University of Leeds',
    'leedsbeckett.ac.uk': 'Leeds Beckett University',
    'lehigh.edu': 'Lehigh University',
    'letu.edu': 'LeTourneau University',
    'lewisu.edu': 'Lewis University',
    'liberty.edu': 'Liberty University',
    'lincoln.ac.uk': 'University of Lincoln',
    'lincoln.edu': 'Lincoln University',
    'lindenwood.edu': 'Lindenwood University',
    'linfield.edu': 'Linfield College',
    'lipscomb.edu': 'Lipscomb University',
    'liu.se': 'Linköping University',
    'liv.ac.uk': 'University of Liverpool',
    'ljmu.ac.uk': 'Liverpool John Moores University',
    'llu.edu': 'Loma Linda University',
    'lmu.edu': 'Loyola Marymount University',
    'lnnu.edu.cn': 'Liaoning Normal University',
    'lnu.edu.cn': 'Liaoning University',
    'lnu.edu.ua': 'Lviv University',
    'lonestar.edu': 'Lone Star College System',
    'longwood.edu': 'Longwood University',
    'loras.edu': 'Loras College',
    'louisiana.edu': 'University of Louisiana at Lafeyette',
    'louisville.edu': 'University of Louisville',
    'lp.edu.ua': 'Lviv Polytechnic National University',
    'lpu.edu.ph': 'Lyceum of the Philippines University',
    'lpu.in': 'Lovely Professional University',
    'lse.ac.uk': 'London School of Economics and Political Science, University of '
                'London',
    'lssu.edu': 'Lake Superior State University',
    'lsu.edu': 'Louisiana State University',
    'ltu.edu': 'Lawrence Technological University',
    'lu.lv': 'University of Latvia',
    'lu.se': 'Lund University',
    'luc.edu': 'Loyola University Chicago',
    'lums.edu.pk': 'Lahore University of Management Sciences',
    'lus.ac.bd': 'Leading University',
    'lut.fi': 'Lappeenranta University of Technology',
    'luther.edu': 'Luther College',
    'lvc.edu': 'Lebanon Valley College',
    'lycoming.edu': 'Lycoming College',
    'lyon.edu': 'Lyon College',
    'lzu.edu.cn': 'Lanzhou University',
    'macalester.edu': 'Macalester College',
    'macewan.ca': 'MacEwan University',
    'machung.ac.id': 'Universitas Ma Chung',
    'mackenzie.br': 'Universidade Mackenzie',
    'mah.se': 'Malmö University College',
    'mahidol.ac.th': 'Mahidol University',
    'mak.ac.ug': 'Makerere University',
    'manarat.ac.bd': 'Manarat International University',
    'manchester.ac.uk': 'University of Manchester',
    'mandela.ac.za': 'Nelson Mandela University',
    'manhattan.edu': 'Manhattan College',
    'manipal.edu': 'Manipal University',
    'manit.ac.in': 'Maulana Azad National Institute of Technology Bhopal',
    'manoa.hawaii.edu': 'University of Hawaii at Manoa',
    'mans.edu.eg': 'Mansoura University',
    'mapua.edu.ph': 'Mapúa University',
    'maranatha.edu': 'Universitas Kristen Maranatha',
    'marist.edu': 'Marist College',
    'marquette.edu': 'Marquette University',
    'marshall.edu': 'Marshall University',
    'marymount.edu': 'Marymount University',
    'maryvillecollege.edu': 'Maryville College',
    'maseno.ac.ke': 'Maseno University',
    'massey.ac.nz': 'Massey University',
    'mbstu.ac.bd': 'Mawlana Bhashani Science And Technology University',
    'mcckc.edu': 'Metropolitan Community College (MO)',
    'mcgill.ca': 'McGill University',
    'mcmaster.ca': 'McMaster University',
    'mcneese.edu': 'McNeese State University',
    'mcu.edu.tw': 'Ming Chuan University',
    'mdc.edu': 'Miami Dade College',
    'mdh.se': 'Mälardalen University',
    'medeniyet.edu.tr': 'Istanbul Medeniyet University',
    'medipol.edu.tr': 'Istanbul Medipol University',
    'mef.edu.tr': 'MEF University',
    'mehmetakif.edu.tr': 'Mehmet Akif Ersoy University',
    'meiji.ac.jp': 'Meiji University',
    'meijo-u.ac.jp': 'Meijo University',
    'memphis.edu': 'University of Memphis',
    'menofia.edu.eg': 'Menoufia University',
    'mercer.edu': 'Mercer University',
    'mercy.edu': 'Mercy College',
    'meredith.edu': 'Meredith College',
    'messiah.edu': 'Messiah College',
    'metropolia.fi': 'Metropolia University of Applied Sciences',
    'metrostate.edu': 'Metropolitan State University',
    'metrouni.edu.bd': 'Metropolitan University',
    'metu.edu.tr': 'Middle East Technical University',
    'meu.edu.jo': 'Middle East University',
    'mgu.ac.in': 'Mahatma Gandhi University, Kerala',
    'miami.edu': 'University of Miami',
    'miamioh.edu': 'Miami University of Ohio',
    'middlebury.edu': 'Middlebury College',
    'middlesexcc.edu': 'Middlesex County College',
    'mie-u.ac.jp': 'Mie University',
    'miet.ru': 'National Research University of Electronic Technology',
    'miit.ru': 'Moscow State University of Railway Transport',
    'millersville.edu': 'Millersville University of Pennsylvania',
    'millsaps.edu': 'Millsaps College',
    'mines.edu': 'Colorado School of Mines',
    'minnesota.edu': 'Minnesota State Community and Technical College',
    'mipt.ru': 'Moscow Institute of Physics and Technology',
    'mirea.ru': 'Moscow State Institute of Radiotechnics, Electronics and '
                'Automation (Technical University)',
    'misis.ru': 'Moscow State Institute of Steel and Alloys',
    'missouri.edu': 'University of Missouri',
    'missouristate.edu': 'Missouri State University',
    'mist.ac.bd': 'Military Institute of Science and Technology',
    'mit.edu': 'Massachusetts Institute of Technology',
    'miun.se': 'Mid-Sweden University',
    'mku.ac.ke': 'Mount Kenya University',
    'mmarau.ac.ke': 'Maasai Mara University',
    'mmu.ac.ke': 'Multimedia University of Kenya',
    'mmu.ac.uk': 'The Manchester Metropolitan University',
    'mmu.edu.my': 'Multimedia University',
    'mnit.ac.in': 'Malaviya National Institute of Technology Jaipur',
    'mnnit.ac.in': 'Motilal Nehru National Institute Of Technology',
    'mnstate.edu': 'Minnesota State University Moorhead',
    'mnsu.edu': 'Minnesota State University, Mankato',
    'modares.ac.ir': 'Tarbiat Modares University',
    'monash.edu.au': 'Monash University',
    'monroecc.edu': 'Monroe Community College',
    'montana.edu': 'Montana State University - Bozeman',
    'montgomerycollege.edu': 'Montgomery College',
    'moorparkcollege.edu': 'Moorpark College',
    'moravian.edu': 'Moravian College',
    'moreheadstate.edu': 'Morehead State University',
    'morehouse.edu': 'Morehouse',
    'morgan.edu': 'Morgan State University',
    'mpc.edu': 'Monterey Peninsula College',
    'mq.edu.au': 'Macquarie University',
    'mrsu.ru': 'Mordovian State University',
    'mrt.ac.lk': 'University of Moratuwa',
    'mshdiau.ac.ir': 'Islamic Azad University, Mashhad',
    'msmary.edu': "Mount St. Mary's University",
    'msoe.edu': 'Milwaukee School of Engineering',
    'msstate.edu': 'Mississippi State University',
    'mst.edu': 'Missouri University of Science and Technology',
    'msu.edu': 'Michigan State University',
    'msu.ru': 'Lomonosov Moscow State University',
    'msubaroda.ac.in': 'Maharaja Sayajirao University of Baroda',
    'msue.edu.mn': 'Mongolian State University of Education',
    'msuiit.edu.ph': 'Mindanao State University - Iligan Institute of Technology',
    'mta.ca': 'Mount Allison University',
    'mtech.edu': 'Montana Tech',
    'mtholyoke.edu': 'Mount Holyoke College',
    'mtroyal.ca': 'Mount Royal University',
    'mtsac.edu': 'Mt. San Antonio College',
    'mtsu.edu': 'Middle Tennessee State University',
    'mtu.edu': 'Michigan Technological University',
    'mtuci.ru': 'Moscow Technical University of Informatics and Communication',
    'mu.ac.in': 'University of Mumbai',
    'mu.ac.ke': 'Moi University',
    'mu.ac.zm': 'Mulungushi University',
    'mu.edu.et': 'Mekelle University',
    'mu.edu.tr': 'Mugla Sitki Kocman University',
    'muc.edu.iq': 'Al Mansour University College',
    'muet.edu.pk': 'Mehran University of Engineering & Technology',
    'muni.cz': 'Masaryk University',
    'murdoch.edu.au': 'Murdoch University',
    'muskingum.edu': 'Muskingum College',
    'must.ac.ke': 'Meru University of Science and Technology',
    'must.edu.eg': 'Misr University for Sience and Technology',
    'must.edu.mn': 'Mongolian University of Science and Technology',
    'mvc.edu': 'Moreno Valley College',
    'mvsu.edu': 'Mississippi Valley State University',
    'mwu.edu.et': 'Madawalabu University',
    'mybrcc.edu': 'Baton Rouge Community College',
    'na.edu': 'North American University',
    'naa.edu.az': 'National Aviation Academy',
    'nagasaki-u.ac.jp': 'Nagasaki University',
    'nagoya-u.ac.jp': 'Nagoya University',
    'nahrainuniv.edu.iq': 'Al Nahrain University',
    'najah.edu': 'An-Najah National University',
    'nanzan-u.ac.jp': 'Nanzan University',
    'nara-wu.ac.jp': "Nara Women's University",
    'nau.edu': 'Northern Arizona University',
    'nbu.edu.cn': 'Ningbo University',
    'ncat.edu': 'North Carolina A&T State University',
    'ncc.edu': 'Nassau Community College',
    'nccu.edu.tw': 'National Chengchi University',
    'ncl.ac.uk': 'University of Newcastle-upon-Tyne',
    'ncsu.edu': 'North Carolina State University',
    'nctc.edu': 'North Central Texas College',
    'nctu.edu.tw': 'National Chiao Tung University',
    'ncu.edu.cn': 'Nanchang University',
    'ncu.edu.tw': 'National Central University',
    'ncuindia.edu': 'NorthCap University',
    'ncyu.edu.tw': 'National Chiayi University',
    'nd.edu': 'University of Notre Dame',
    'ndhu.edu.tw': 'National Dong Hwa University',
    'ndmu.edu.ph': 'Notre Dame of Marbel University',
    'ndsu.edu': 'North Dakota State University',
    'neau.edu.cn': 'Northeast Agricultural University',
    'nefu.edu.cn': 'Northeast Forest University',
    'nenu.edu.cn': 'Northeast Normal University',
    'neu.edu.cn': 'Northeastern University',
    'neu.edu.tr': 'Near East University',
    'neu.edu.vn': 'Hanoi National Economics University',
    'neub.edu.bd': 'North East University Bangladesh',
    'neusoft.edu.cn': 'Dalian Neusoft University of Information',
    'newcastle.edu.au': 'University of Newcastle',
    'newhaven.edu': 'University of New Haven',
    'nfu.edu.tw': 'National Formosa University',
    'nhh.no': 'Norwegian School of Economics and Business Administration',
    'ni.ac.rs': 'University of Nis',
    'nihon-u.ac.jp': 'Nihon University',
    'nirmauni.ac.in': 'Nirma University',
    'nit.ac.ir': 'Babol Noshirvani University of Technology',
    'nita.ac.in': 'National Institute of Technology Agartala',
    'nitc.ac.in': 'National Institute of Technology Calicut',
    'nitdelhi.ac.in': 'National Institute of Technology Delhi',
    'nitdgp.ac.in': 'National Institute of Technology Durgapur',
    'nitech.ac.jp': 'Nagoya Institute of Technology',
    'nitgoa.ac.in': 'National Institute of Technology Goa',
    'nith.ac.in': 'National Institute of Technology Hamirpur',
    'nitj.ac.in': 'Dr. B. R. Ambedkar National Institute of Technology Jalandhar',
    'nitjsr.ac.in': 'National Institute of Technology Jamshedpur',
    'nitk.ac.in': 'National Institute of Technology Surathkal',
    'nitmanipur.ac.in': 'National Institute of Technology Manipur',
    'nitmz.ac.in': 'National Institute of Technology Mizoram',
    'nitnagaland.ac.in': 'National Institute of Technology Nagaland',
    'nitp.ac.in': 'National Institute of Technology Patna',
    'nitrkl.ac.in': 'National Institute of Technology Rourkela',
    'nitrr.ac.in': 'National Institute of Technology Raipur',
    'nits.ac.in': 'National Institute of Technology Silchar',
    'nitsikkim.ac.in': 'National Institute of Technology Sikkim',
    'nitt.edu': 'National Institute of Technology Trichy',
    'nituk.ac.in': 'National Institute of Technology Uttarakhand',
    'niu.edu': 'Northern Illinois University',
    'niu.edu.tw': 'National Ilan University',
    'njit.edu': 'New Jersey Institute of Technology',
    'nju.edu.cn': 'Nanjing University',
    'njupt.edu.cn': 'Nanjing University of Posts and Telecommunications',
    'njust.edu.cn': 'Nanjing University of Science and Technology',
    'nknu.edu.tw': 'National Kaohsiung Normal University',
    'nku.edu': 'Northern Kentucky University',
    'nkumbauniversity.ac.ug': 'Nkumba University',
    'nmsu.edu': 'New Mexico State University',
    'nmt.edu': 'New Mexico Institute of Mining & Technology',
    'nmu.ac.in': 'North Maharashtra University',
    'nmu.edu': 'Northern Michigan University',
    'nmu.org.ua': 'National Mining University',
    'northampton.edu': 'Northampton Community College',
    'northeastern.edu': 'Northeastern University',
    'northeaststate.edu': 'Northeast State Community College',
    'northsouth.edu': 'North South University',
    'northwestern.edu': 'Northwestern University',
    'northwood.edu': 'Northwood University',
    'norwich.edu': 'Norwich University',
    'nottingham.ac.uk': 'University of Nottingham',
    'nottingham.edu.cn': 'The University of Nottingham Ningbo China',
    'nova.edu': 'Nova Southeastern University',
    'nsit.ac.in': 'Netaji Subhas Institute of Technology',
    'nstu.edu.bd': 'Noakhali University of Science and Technology',
    'nstu.ru': 'Novosibirsk State Technical University',
    'nsu.edu': 'Norfolk State University',
    'nsu.ru': 'Novosibirsk State University',
    'nsula.edu': 'Northwestern State University',
    'nsuok.edu': 'Northeastern State University',
    'nsysu.edu.tw': 'National Sun Yat-Sen University',
    'nthu.edu.tw': 'National Tsinghua University',
    'ntnu.edu.tw': 'National Taiwan Normal University',
    'ntou.edu.tw': 'National Taiwan Ocean University',
    'ntu.ac.uk': 'Nottingham Trent University',
    'ntu.edu.sg': 'Nanyang Technological University',
    'ntu.edu.tw': 'National Taiwan University',
    'ntua.gr': 'National Technical University of Athens',
    'ntust.edu.tw': 'National Taiwan University of Science and Technology',
    'ntut.edu.tw': 'National Taipei University of Technology',
    'nu.edu.af': 'Nangarhar University',
    'nu.edu.eg': 'Nile University',
    'nu.edu.pk': 'FAST - National University of Computer and Emerging Sciences '
                '(NUCES)',
    'nuaa.edu.cn': 'Nanjing University of Aeronautics and Astronautics',
    'nudt.edu.cn': 'National University of Defense Technology',
    'nuigalway.ie': 'National University of Ireland, Galway',
    'nuis.ac.jp': 'Niigata University of International and Information Studies',
    'num.edu.mn': 'Mongolian National University',
    'nuol.edu.la': 'National University of Laos',
    'nure.ua': 'Kharkiv National University of Radio Electronics',
    'nus.edu.sg': 'National University of Singapore',
    'nust.ac.zw': 'National University of Science and Technology Bulawayo',
    'nust.edu.pk': 'National University of Science and Technology',
    'nuu.edu.tw': 'National United University',
    'nuu.uz': 'National University of Uzbekistan',
    'nwciowa.edu': 'Northwestern College of Iowa',
    'nwmissouri.edu': 'Northwest Missouri State University',
    'nwpu.edu.cn': "Northwest Polytechnical University Xi'an",
    'nwu.edu.cn': "Northwest University Xi'an",
    'nyit.edu': 'New York Institute of Technology',
    'nyu.edu': 'New York University',
    'nyuad.nyu.edu': 'New York University, Abu Dhabi',
    'o6u.edu.eg': 'October 6 university',
    'oakland.edu': 'Oakland University',
    'oaklandcc.edu': 'Oakland Community College',
    'oakton.edu': 'Oakton Community College',
    'oauife.edu.ng': 'Obafemi Awolowo University Ile-Ife',
    'oberlin.edu': 'Oberlin College',
    'oc.edu': 'Oklahoma Christian University',
    'ocha.ac.jp': "Ochanomizu Women's University",
    'odu.edu': 'Old Dominion University',
    'ogu.edu.tr': 'Osmangazi University',
    'ohio.edu': 'Ohio University',
    'ohsu.edu': 'Oregon Health Sciences University',
    'oit.ac.jp': 'Osaka Institute of Technology',
    'oit.edu': 'Oregon Institute of Technology',
    'oita-u.ac.jp': 'Oita University',
    'oiu.edu.sd': 'Omdurman Islamic University',
    'oka-pu.ac.jp': 'Okayama Prefectural University',
    'okanagan.bc.ca': 'Okanagan University College',
    'okayama-u.ac.jp': 'Okayama University',
    'okcu.edu': 'Oklahoma City University',
    'okstate.edu': 'Oklahoma State University',
    'olemiss.edu': 'University of Mississippi',
    'olivet.edu': 'Olivet Nazarene University',
    'omgtu.ru': 'Omsk State Technical University',
    'ontariotechu.ca': 'Ontario Tech University',
    'onu.edu': 'Ohio Northern University',
    'onu.edu.ua': 'Odessa National I.I. Mecnikov University',
    'open.ac.uk': 'Open University',
    'openu.ac.il': 'Open University of Israel',
    'orangecoastcollege.edu': 'Orange Coast College',
    'oregonstate.edu': 'Oregon State University',
    'ort.edu.uy': 'Universidad ORT Uruguay',
    'oru.edu': 'Oral Roberts University',
    'oru.se': 'Örebro University',
    'osaka-u.ac.jp': 'Osaka University',
    'osakac.ac.jp': 'Osaka Electro-Communication University',
    'osakafu-u.ac.jp': 'Osaka Prefectural University',
    'osmania.ac.in': 'Osmania University',
    'osu.edu': 'Ohio State University, Columbus',
    'osu.ru': 'Orenburg State University',
    'oswego.edu': 'State University of New York at Oswego',
    'otago.ac.nz': 'University of Otago',
    'otc.edu': 'Ozarks Technical Community College',
    'otterbein.edu': 'Otterbein College',
    'ou.edu': 'University of Oklahoma',
    'ou.edu.vn': 'Ho Chi Minh City Open University',
    'ou.nl': 'Open University of the Netherlands',
    'ouc.edu.cn': 'Ocean University of China',
    'ouhk.edu.hk': 'Open University of Hong Kong',
    'oulu.fi': 'University of Oulu',
    'oum.edu.my': 'Open University Malaysia',
    'ous.ac.jp': 'Okayama University of Science',
    'owu.edu': 'Ohio Wesleyan University',
    'ox.ac.uk': 'University of Oxford',
    'ozyegin.edu.tr': 'Ozyegin University',
    'p.lodz.pl': 'Technical University of Lodz',
    'pace.edu': 'Pace University',
    'pacific.edu': 'University of the Pacific',
    'pacificu.edu': 'Pacific University',
    'pafkiet.edu.pk': 'Karachi Institute Of Economics And Technology',
    'parisjc.edu': 'Paris Junior College',
    'park.edu': 'Park University',
    'parkland.edu': 'Parkland College',
    'paruluniversity.ac.in': 'Parul University',
    'pasadena.edu': 'Pasadena City College',
    'pcc.edu': 'Portland Community College',
    'pct.edu': 'Pennsylvania College of Technology',
    'pdn.ac.lk': 'University of Peradeniya',
    'pdx.edu': 'Portland State University',
    'pec.ac.in': 'Punjab Engineering College',
    'peru.edu': 'Peru State College',
    'pes.edu': 'Pes University',
    'petra.ac.id': 'Universitas Kristen Petra',
    'pgcc.edu': "Prince George's Community College",
    'pgu.ac.ir': 'Persian Gulf University',
    'phoenix.edu': 'University of Phoenix',
    'piau.ac.ir': 'Islamic Azad University, Parand',
    'pierce.ctc.edu': 'Pierce College at Puyallup',
    'pitt.edu': 'University of Pittsburgh',
    'pittstate.edu': 'Pittsburg State University',
    'pk.edu.pl': 'Technical University of Cracow',
    'pknu.ac.kr': 'Pukyong National University',
    'pku.edu.cn': 'Peking University',
    'plm.edu.ph': 'University of the City of Manila',
    'plu.edu': 'Pacific Lutheran University',
    'plymouth.ac.uk': 'University of Plymouth',
    'plymouth.edu': 'Plymouth State College',
    'pntu.edu.ua': 'Poltava National Technical University',
    'pnu.ac.ir': 'Payame Noor University',
    'pnw.edu': 'Purdue University Northwest',
    'pnzgu.ru': 'Penza State University',
    'polban.ac.id': 'Politeknik Negeri Bandung',
    'poliba.it': 'Polytechnic Institute of Bari',
    'polimi.it': 'Polytechnic Institute of Milan',
    'polito.it': 'Polytechnic Institute of Turin',
    'polito.uz': 'Turin Polytechnic University In Tashkent',
    'polk.edu': 'Polk State College',
    'polsl.pl': 'Silesian Technical University of Gliwice',
    'polymtl.ca': 'École Polytechnique de Montréal, Université de Montréal',
    'polytechnique.edu': 'École Polytechnique',
    'polyu.edu.hk': 'Hong Kong Polytechnic University',
    'pomona.edu': 'Pomona College',
    'port.ac.uk': 'University of Portsmouth',
    'postech.ac.kr': 'Pohang University of Science and Technology',
    'ppke.hu': 'Pázmány Péter Catholic University',
    'presidency.edu.bd': 'Presidency University',
    'princeton.edu': 'Princeton University',
    'providence.edu': 'Providence College',
    'psgtech.edu': 'PSG College of Technology',
    'pstcc.edu': 'Pellissippi State Community College',
    'pstu.ac.bd': 'Patuakhali Science and Technology University',
    'psu.ac.th': 'Prince of Songkla University',
    'psu.by': 'Polotsk State University',
    'psu.edu': 'Pennsylvania State University',
    'psu.ru': 'Perm State University',
    'psut.edu.jo': 'Princess Sumaya University for Technology',
    'ptit.edu.vn': 'Posts & Telecommunications Institute of Technology',
    'ptu.ac.in': 'Punjab Technical University',
    'ptuk.edu.ps': 'Palestine Technical University - Kadoorie',
    'pu.edu.tw': 'Providence University',
    'pua.edu.eg': 'Pharos International University',
    'pub.ac.bd': "People's University of Bangladesh",
    'puc-rio.br': 'Pontifícia Universidade Católica do Rio de Janeiro',
    'puc.ac.bd': 'Premier University',
    'puce.edu.ec': 'Pontificia Universidad Católica del Ecuador',
    'puchd.ac.in': 'Panjab University',
    'pucit.edu.pk': 'Punjab University College of Information Tecnology',
    'pucminas.br': 'Pontifícia Universidade Católica de Minas Gerais',
    'pucmm.edu.do': 'Pontificia Universidad Católica Madre y Maestra (PUCMM)',
    'pucp.edu.pe': 'Pontificia Universidad Católica del Perú',
    'pucpr.br': 'Pontificia Universidade Católica do Paraná',
    'pucrs.br': 'Pontifícia Universidade Católica do Rio Grande do Sul',
    'pucsp.br': 'Pontifícia Universidade Católica de São Paulo',
    'pup.edu.ph': 'Polytechnic University of the Philippines',
    'purdue.edu': 'Purdue University',
    'pusan.ac.kr': 'Pusan National University',
    'pust.ac.bd': 'Pabna University of Science and Technology',
    'put.ac.ir': 'Petroleum University of Technology',
    'put.poznan.pl': 'Technical University of Poznan',
    'pvamu.edu': 'Prairie View A&M University',
    'pw.edu.pl': 'Warsaw University of Technology',
    'pwr.edu.pl': 'Technical University of Wroclaw',
    'pwsz.eu': 'Walcz College',
    'qc.cuny.edu': 'CUNY Queens College',
    'qdu.edu.cn': 'Qingdao University',
    'qfnu.edu.cn': 'Qufu Normal University',
    'qiau.ac.ir': 'Islamic Azad University, Qazvin',
    'qmul.ac.uk': 'Queen Mary, University of London',
    'qom.ac.ir': 'Qom University',
    'qu.edu.az': 'Qafqaz University',
    'qu.edu.qa': 'University of Qatar',
    'qub.ac.uk': "The Queen's University Belfast",
    'queensu.ca': "Queen's University",
    'quincy.edu': 'Quincy University',
    'qut.edu.au': 'Queensland University of Technology',
    'radford.edu': 'Radford University',
    'ramapo.edu': 'Ramapo College',
    'rau.am': 'Russian-Armenian (Slavonic) State University',
    'razi.ac.ir': 'Razi University',
    'rcc.edu': 'Norco College',
    'rea.ru': 'Plekhanov Russian Academy of Economics',
    'reduc.edu.cu': 'Universidad de Camagüey',
    'reed.edu': 'Reed College',
    'regis.edu': 'Regis University',
    'reitaku-u.ac.jp': 'Reitaku University',
    'rgu.ac.uk': 'The Robert Gordon University',
    'rhodes.edu': 'Rhodes College',
    'rice.edu': 'Rice University',
    'ripon.edu': 'Ripon College',
    'rit.edu': 'Rochester Institute of Technology',
    'ritsumei.ac.jp': 'Ritsumeikan University',
    'rmc.edu': 'Randolph-Macon College',
    'rmit.edu.au': 'Royal Melbourne Institute of Technology',
    'rmit.edu.vn': 'RMIT International University Vietnam',
    'rmu.edu': 'Robert Morris University',
    'roanoke.edu': 'Roanoke College',
    'rochester.edu': 'University of Rochester',
    'rockford.edu': 'Rockford College',
    'rockhurst.edu': 'Rockhurst College',
    'rocky.edu': 'Rocky Mountain College',
    'roehampton.ac.uk': 'Roehampton University of Surrey',
    'rose-hulman.edu': 'Rose-Hulman Institute of Technology',
    'rowan.edu': 'Rowan College',
    'royalholloway.ac.uk': 'Royal Holloway and Bedford New College',
    'rpi.edu': 'Rensselaer Polytechnic Institute',
    'rshu.ru': 'Russian State Hydrometeorological University',
    'rsu.edu': 'Rogers State University',
    'rtu.ac.in': 'Rajasthan Technical University',
    'rtu.lv': 'Riga Technical University',
    'ru.ac.bd': 'University of Rajshahi',
    'ru.ac.za': 'Rhodes University',
    'ru.is': 'Reykjavík University',
    'ru.nl': 'Radboud University',
    'rub.edu.bt': 'Royal University of Bhutan',
    'ruc.dk': 'Roskilde University',
    'ruc.edu.cn': 'Renmin University of China',
    'ruet.ac.bd': 'Rajshahi University of Engineering and Technology',
    'rug.nl': 'University of Groningen',
    'ruhr-uni-bochum.de': 'Ruhr-Universität Bochum',
    'rusoil.net': 'Ufa State Petroleum Technological University',
    'rutgers.edu': 'Rutgers University',
    'rwth-aachen.de': 'Rheinisch Westfälische Technische Hochschule Aachen',
    'ryukoku.ac.jp': 'Ryukoku University',
    'sabanciuniv.edu': 'Sabanci University',
    'sacredheart.edu': 'Sacred Heart University',
    'saddleback.edu': 'Saddleback College',
    'sadjad.ac.ir': 'Sadjad Institute of Technology',
    'sait.ca': 'Southern Alberta Institute of Technology',
    'saitama-u.ac.jp': 'Saitama University',
    'sakarya.edu.tr': 'Sakarya University',
    'salam.edu.af': 'Salam University',
    'salford.ac.uk': 'University of Salford',
    'salisbury.edu': 'Salisbury University',
    'samdu.uz': 'Samarkand State University',
    'samford.edu': 'Samford University',
    'sandiego.edu': 'University of San Diego',
    'sangji.ac.kr': 'Sang Ji University',
    'sastra.edu': 'SASTRA Deemed University',
    'sau.edu': 'St. Ambrose University',
    'saurashtrauniversity.edu': 'Saurashtra University',
    'saxion.edu': 'Saxion Universities',
    'sbcc.edu': 'Santa Barbara City College',
    'sbu.ac.ir': 'Shahid Beheshti University',
    'sbuniv.edu': 'Southwest Baptist University',
    'sc.edu': 'University of South Carolina',
    'scau.edu.cn': 'South China Agricultural University',
    'schoolcraft.edu': 'Schoolcraft College',
    'scnu.edu.cn': 'South China Normal University',
    'scranton.edu': 'University of Scranton',
    'scu.ac.ir': 'Shahid Chamran University of Ahvaz',
    'scu.edu': 'Santa Clara University',
    'scu.edu.cn': 'Sichuan University',
    'scut.edu.cn': 'South China University of Technology',
    'sdmesa.edu': 'San Diego Mesa College',
    'sdnu.edu.cn': 'Shandong Normal University',
    'sdsmt.edu': 'South Dakota School of Mines and Technology',
    'sdstate.edu': 'South Dakota State University',
    'sdsu.edu': 'San Diego State University',
    'sdu.dk': 'University of Southern Denmark - SDU',
    'sdu.edu.cn': 'Shandong University',
    'sdu.edu.kz': 'Suleyman Demirel University',
    'sdufe.edu.cn': 'Shandong University of Finance and Economics',
    'sdust.edu.cn': 'Shandong University of Science and Technology',
    'sdut.edu.cn': 'Shandong University of Technology',
    'seattleu.edu': 'Seattle University',
    'sec.ac.bd': 'Sylhet Engineering College',
    'sehir.edu.tr': 'Istanbul Şehir University',
    'sejong.ac.kr': 'Sejong University',
    'selcuk.edu.tr': 'Selcuk University',
    'semnan.ac.ir': 'Semnan University',
    'semo.edu': 'Southeast Missouri State University',
    'semyung.ac.kr': 'Semyung University',
    'senshu-u.ac.jp': 'Senshu University',
    'seoultech.ac.kr': 'Seoul National University of Science and Technology',
    'seu.ac.bd': 'Southeast University',
    'seu.edu.cn': 'Southeast University',
    'sewanee.edu': 'Sewanee, University of the South',
    'sfasu.edu': 'Stephen F. Austin State University',
    'sfsu.edu': 'San Francisco State University',
    'sfu.ca': 'Simon Fraser University',
    'sgau.ru': 'Saratov State Agrarian University',
    'sgu.ac.id': 'Swiss German University',
    'sgu.edu.cn': 'Shaoguan University',
    'sgu.edu.vn': 'Saigon University',
    'sgu.ru': 'Saratov State University',
    'sh.se': 'Södertörn University College',
    'shahed.ac.ir': 'Shahed University',
    'shahroodut.ac.ir': 'Shahrood University of Technology',
    'sharjah.ac.ae': 'University of Sharjah',
    'shbu.ac.ir': 'Sheikh Bahaei University',
    'sheffield.ac.uk': 'University of Sheffield',
    'sheridancollege.ca': 'Sheridan College',
    'shinshu-u.ac.jp': 'Shinshu University',
    'ship.edu': 'Shippensburg University of Pennsylvania',
    'shirazu.ac.ir': 'Shiraz University',
    'shmtu.edu.cn': 'Shanghai Maritime University',
    'shobhituniversity.ac.in': 'Shobhit University, Meerut',
    'shomal.ac.ir': 'Shomal University',
    'shonan-it.ac.jp': 'Shonan Institute of Technology',
    'shoreline.edu': 'Shoreline Community College',
    'shsu.edu': 'Sam Houston State University',
    'shu.edu.cn': 'Shanghai University',
    'sierracollege.edu': 'Sierra College',
    'simons-rock.edu': "Simon's Rock College",
    'simpson.edu': 'Simpson College',
    'siu.edu': 'Southern Illinois University-Carbondale',
    'siu.edu.bd': 'Sylhet International University',
    'siu.edu.in': 'Symbiosis International University',
    'siue.edu': 'Southern Illinois University-Edwardsville',
    'sjsu.edu': 'San Jose State University',
    'sjtu.edu.cn': 'Shanghai Jiaotong University',
    'sju.edu': "Saint Joseph's University",
    'sjzu.edu.cn': 'Shenyang Jianzhu University',
    'skhu.ac.kr': 'Sungkonghoe University',
    'skku.edu': 'Sungkyunkwan University',
    'sliit.lk': 'Sri Lanka Institute of Information Technology (SLIT)',
    'slu.edu': 'Saint Louis University',
    'slu.edu.ph': 'Saint Louis University',
    'slu.se': 'Swedish University of Agricultural Sciences',
    'smc.edu': 'Santa Monica College',
    'smcm.edu': "St. Mary's College of Maryland",
    'smcvt.edu': "Saint Michael's College",
    'smith.edu': 'Smith College',
    'smsu.edu': 'Southwest Missouri State University',
    'smtu.ru': 'St. Petersburg State Marine Technical University',
    'smu.ac.kr': 'Sangmyung University',
    'smu.ca': "St. Mary's University",
    'smu.edu': 'Southern Methodist University',
    'smu.edu.in': 'Sikkim Manipal University of Health, Medical and Technological '
                'Sciences',
    'smu.edu.sg': 'Singapore Management University',
    'smumn.edu': "Saint Mary's University of Minnesota",
    'snhu.edu': 'Southern New Hampshire University',
    'snnu.edu.cn': 'Shaanxi Normal University',
    'sns.it': 'School of Education Pisa',
    'snu.ac.kr': 'Seoul National University',
    'soauniversity.ac.in': "Sikha 'O' Anushandhan University",
    'sogang.ac.kr': 'Sogang University',
    'soka.ac.jp': 'Soka University',
    'solent.ac.uk': 'Southampton Solent University',
    'somaiya.edu': 'Somaiya Vidyavihar',
    'sonoma.edu': 'Sonoma State University',
    'sookmyung.ac.kr': "Sookmyung Women's University",
    'sorbonne-universite.fr': 'Sorbonne Université - Faculté des Sciences (Paris '
                            'VI)',
    'southalabama.edu': 'University of South Alabama',
    'southernct.edu': 'Southern Connecticut State University',
    'southwestern.edu': 'Southwestern University',
    'southwesterncc.edu': 'Southwestern Community College',
    'spbau.ru': 'Academic University',
    'spbgasu.ru': 'St. Petersburg State University of Architecture and Civil '
                'Engineering',
    'spbstu.ru': 'St. Petersburg State Polytechnical University',
    'spbu.ru': 'St. Petersburg State University',
    'spu.ac.ke': 'St. Pauls University',
    'spu.edu': 'Seattle Pacific University',
    'squ.edu.om': 'Sultan Qaboos University',
    'sru.edu': 'Slippery Rock University of Pennsylvania',
    'ssau.ru': 'Samara State Aerospace University',
    'ssu.ac.kr': 'Soongsil University',
    'ssuet.edu.pk': 'Sir Syed University of Engineering and Technology',
    'st-andrews.ac.uk': 'University of St. Andrews',
    'stamforduniversity.edu.bd': 'Stamford University',
    'stanford.edu': 'Stanford University',
    'stankin.ru': 'Moscow State University of Technology (Stankin)',
    'stchas.edu': 'St Charles Community College',
    'stcloudstate.edu': 'Saint Cloud State University',
    'stedwards.edu': "Saint Edward's University",
    'stetson.edu': 'Stetson University',
    'stevens.edu': 'Stevens Institute of Technology',
    'stevenscollege.edu': 'Thaddeus Stevens College of Technology',
    'stfx.ca': 'St. Francis Xavier University',
    'stir.ac.uk': 'University of Stirling',
    'stjohns.edu': "Saint John's University (NY)",
    'stlawu.edu': 'St. Lawrence University',
    'stockton.edu': 'Richard Stockton College of New Jersey',
    'stolaf.edu': 'Saint Olaf College',
    'stonybrook.edu': 'State University of New York at Stony Brook',
    'strath.ac.uk': 'University of Strathclyde',
    'strathmore.edu': 'Strathmore University',
    'strayer.edu': 'Strayer College',
    'stthomas.edu': 'University of Saint Thomas (MN)',
    'stu.edu.cn': 'Shantou University',
    'stu.lipetsk.ru': 'Lipeck State Technical University',
    'stu.ru': 'Siberian State Transport University',
    'stuba.sk': 'Slovak University of Technology in Bratislava',
    'su.edu.ph': 'Silliman University',
    'su.se': 'Stockholm University',
    'suai.ru': 'St. Petersburg State University of Aerospace Instrumentation',
    'suda.edu.cn': 'Suzhou University',
    'sumdu.edu.ua': 'Sumy State University',
    'sun.ac.za': 'University of Stellenbosch',
    'sungkyul.ac.kr': 'Sungkyul University',
    'sunmoon.ac.kr': 'Sunmoon University',
    'surrey.ac.uk': 'University of Surrey',
    'suscc.edu': 'Southern Union State Community College',
    'susqu.edu': 'Susquehanna University',
    'sussex.ac.uk': 'University of Sussex',
    'sust.edu': 'Shahjalal University of Science and Technology',
    'sustc.edu.cn': 'South University of Science and Technology of China',
    'sustech.edu': 'Sudan University for Science and Technology',
    'sut.ac.ir': 'Sahand University of Technology',
    'sut.ac.th': 'Suranaree University of Technology',
    'sut.ru': 'St. Petersburg State University of Telecommunication',
    'sutech.ac.ir': 'Shiraz University of Technology',
    'suu.edu': 'Southern Utah University',
    'svnit.ac.in': 'Sardar Vallabhbhai National Institute of Technology',
    'svsu.edu': 'Saginaw Valley State University',
    'svu.edu.eg': 'South Valley University',
    'svuonline.org': 'Syrian Virtual University',
    'swansea.ac.uk': 'Swansea University',
    'swarthmore.edu': 'Swarthmore College',
    'swic.edu': 'Southwestern Illinois College',
    'swjtu.edu.cn': 'Southwest Jiaotong University',
    'swpu.edu.cn': 'Southwest Petroleum University',
    'swu.ac.kr': "Seoul Women's University",
    'swun.edu.cn': 'Southwest University of Nationalities',
    'swust.edu.cn': 'Southwest University of Science and Technology',
    'sxu.edu': 'Saint Xavier University',
    'sydney.edu.au': 'University of Sydney',
    'syr.edu': 'Syracuse University',
    'syu.edu.cn': 'Shenyang University',
    'szu.edu.cn': 'Shenzhen University',
    'tabor.edu': 'Tabor College',
    'tabrizu.ac.ir': 'Tabriz University',
    'tamu.edu': 'Texas A&M University - College Station',
    'tamucc.edu': 'Texas A&M University - Corpus Christi',
    'tamuk.edu': 'Texas A&M University - Kingsville',
    'tanta.edu.eg': 'Tanta University',
    'tarc.edu.my': 'Tunku Abdul Rahman Chinese College',
    'tau.ac.il': 'Tel Aviv University',
    'taylors.edu.my': "Taylor's University College",
    'tcd.ie': 'University of Dublin, Trinity College',
    'tcnj.edu': 'The College of New Jersey',
    'tcu.edu': 'Texas Christian University',
    'tdtu.uz': 'Tashkent State Technical University',
    'technion.ac.il': 'Technion - Israel Institute of Technology',
    'tedu.edu.tr': 'TED University',
    'teilar.gr': 'Technological Education Institute of Larissa',
    'teithe.gr': 'Technological Education Institute of Thessaloniki',
    'telkomuniversity.ac.id': 'Universitas Telkom',
    'temple.edu': 'Temple University',
    'teu.ac.jp': 'Tokyo Engineering University',
    'tezu.ernet.in': 'Tezpur University',
    'thm.de': 'Technische Hochschule Mittelhessen',
    'tishreen.edu.sy': 'Tishreen University',
    'titech.ac.jp': 'Tokyo Institute of Technology',
    'tjpu.edu.cn': 'Tianjin Polytechnic University',
    'tju.edu.cn': 'Tianjin University',
    'tku.edu.tw': 'Tamkang University',
    'tltsu.ru': 'Togliatti State University',
    'tmcc.edu': 'Truckee Meadows Community College',
    'tnstate.edu': 'Tennessee State University',
    'tntech.edu': 'Tennessee Technological University',
    'tohoku-gakuin.ac.jp': 'Tohoku Gakuin University',
    'tohoku.ac.jp': 'Tohoku University',
    'toin.ac.jp': 'Toin University of Yokohama',
    'tongji.edu.cn': 'Tongji University',
    'torontomu.ca': 'Toronto Metropolitan University',
    'touro.edu': 'Touro College',
    'towson.edu': 'Towson University',
    'toyo.ac.jp': 'Toyo University',
    'tp.edu.sg': 'Temasek Polytechnic',
    'tpu.ru': 'Tomsk Polytechnic University',
    'transy.edu': 'Transylvania University',
    'trentu.ca': 'Trent University',
    'tribhuvan-university.edu.np': 'Tribhuvan University Kathmandu',
    'trincoll.edu': 'Trinity College (CT)',
    'trine.edu': 'Trine University',
    'trinity.edu': 'Trinity University',
    'troy.edu': 'Troy University',
    'tru.ca': 'Thompson Rivers University',
    'truman.edu': 'Truman State University',
    'tsinghua.edu.cn': 'Tsinghua University',
    'tsu.ru': 'Tomsk State University',
    'tsu.tula.ru': 'Tula State University',
    'tsuda.ac.jp': 'Tsuda College',
    'tsukuba.ac.jp': 'Tsukuba University',
    'ttu.edu': 'Texas Tech University',
    'ttu.edu.tw': 'TaTung University',
    'ttu.ee': 'Tallinn University of Technology',
    'tu-berlin.de': 'Technische Universität Berlin',
    'tu-braunschweig.de': 'Technische Universität Carolo-Wilhelmina zu '
                        'Braunschweig',
    'tu-bryansk.ru': 'Brjansk State Technical University',
    'tu-darmstadt.de': 'Technische Universität Darmstadt',
    'tu-dortmund.de': 'Technische Universität Dortmund',
    'tu-dresden.de': 'Technische Universität Dresden',
    'tu-ilmenau.de': 'Technische Universität Ilmenau',
    'tu.ac.th': 'Thammasat University',
    'tu.edu.iq': 'Tikrit University',
    'tu.edu.sa': 'Taif University',
    'tu.kielce.pl': 'Technical University of Kielce',
    'tuat.ac.jp': 'Tokyo University of Agriculture and Technology',
    'tuc.gr': 'Technical University of Crete',
    'tudelft.nl': 'Delft University of Technology',
    'tue.nl': 'Eindhoven University of Technology',
    'tufts.edu': 'Tufts University',
    'tugab.bg': 'Technical University of Gabrovo',
    'tugraz.at': 'Technische Universität Graz',
    'tuhh.de': 'Technische Universität Hamburg',
    'tuiasi.ro': 'Technical University of Iasi',
    'tuit.uz': 'Tashkent University of Information Technologies',
    'tuke.sk': 'Technical University in Kosice',
    'tukenya.ac.ke': 'Technical University of Kenya',
    'tum.de': 'Technische Universität München',
    'tums.ac.ir': 'Tehran University of Medical Sciences',
    'tup.edu.ph': 'Technological University of the Philippines',
    'tuskegee.edu': 'Tuskegee University',
    'tusur.ru': 'Tomsk State University of Control Systems and Radioelectronics',
    'tut.ac.jp': 'Toyohashi University of Technology',
    'tuwien.ac.at': 'Technische Universität Wien',
    'twu.ca': 'Trinity Western University',
    'twu.edu': "Texas Woman's University",
    'txstate.edu': 'Texas State University',
    'u-aizu.ac.jp': 'University of Aizu',
    'u-szeged.hu': 'University of Szeged',
    'u-tokyo.ac.jp': 'Tokyo University',
    'ua.edu': 'The University of Alabama',
    'ua.es': 'Universidad de Alicante',
    'ua.pt': 'Universidade de Aveiro',
    'uaa.mx': 'Universidad Autónoma de Aguascalientes',
    'uab.edu': 'University of Alabama at Birmingham',
    'uab.ro': '1 December University of Alba Iulia',
    'uac.bj': "Université d'Abomey-Calavi (UAC)",
    'uacam.mx': 'Universidad Autónoma de Campeche',
    'uade.edu.ar': 'Universidad Argentina de la Empresa',
    'uadec.mx': 'Universidad Autónoma de Coahuila',
    'uader.edu.ar': 'Universidad Autónoma de Entre Ríos',
    'uady.mx': 'Universidad Autónoma de Yucatán',
    'uaem.mx': 'Universidad Autónoma del Estado de Morelos',
    'uaeu.ac.ae': 'United Arab Emirates University',
    'uaf.edu': 'University of Alaska - Fairbanks',
    'uafs.edu': 'University of Arkansas - Fort Smith',
    'uag.mx': 'Universidad Autónoma de Guadalajara',
    'uagrm.edu.bo': 'Universidad Autónoma Gabriel René Moreno',
    'uah.edu': 'University of Alabama at Huntsville',
    'uah.es': 'Universidad de Alcalá de Henares',
    'uaic.ro': 'University of Iasi',
    'uajms.edu.bo': 'Universidad Autónoma Juan Misael Saracho',
    'uajy.ac.id': 'Universitas Atma Jaya Yogyakarta',
    'uakron.edu': 'University of Akron',
    'ualberta.ca': 'University of Alberta',
    'ualg.pt': 'Universidade do Algarve',
    'ualr.edu': 'University of Arkansas - Little Rock',
    'uam.edu.ng': 'University of Agriculture Makurdi',
    'uam.es': 'Universidad Autónoma de Madrid',
    'uan.ao': 'Univesidade Agostinho Neto',
    'uanl.mx': 'Universidad Autónoma de Nuevo León',
    'uap-bd.edu': 'University of Asia Pacific, Dhanmondi',
    'uaq.mx': 'Universidad Autónoma de Querétaro',
    'uark.edu': 'University of Arkansas - Fayetteville',
    'uasd.edu.do': 'Universidad Autónoma de Santo Domingo',
    'uaslp.mx': 'Universidad Autónoma de San Luis Potosí',
    'uatf.edu.bo': 'Universidad Autónoma Tomás Frías',
    'uatx.mx': 'Universidad Autónoma de Tlaxcala',
    'ub.ac.id': 'Universitas Brawijaya',
    'ub.edu.ph': 'University of Batangas',
    'uba.ar': 'Universidad de Buenos Aires',
    'ubaya.ac.id': 'Universitas Surabaya',
    'ubbcluj.ro': 'Babes-Bolyai University of Cluj-Napoca',
    'ubc.ca': 'University of British Columbia',
    'ubiobio.cl': 'Universidad del Bío-Bío',
    'ubm.ac.id': 'Universitas Bunda Mulia Jakarta',
    'ubuea.cm': 'Université de Buéa',
    'uc.cl': 'Pontificia Universidad Catolica de Chile',
    'uc.edu': 'University of Cincinnati',
    'uc.edu.ve': 'Universidad de Carabobo',
    'uc.pt': 'Universidade de Coimbra',
    'uca.edu': 'University of Central Arkansas',
    'uca.edu.sv': 'Universidad Centroamericana "José Simeón Canas"',
    'ucab.edu.ve': 'Universidad Católica Andres Bello',
    'ucad.sn': 'Université Cheikh Anta Diop',
    'ucalgary.ca': 'University of Calgary',
    'ucatolica.edu.co': 'Universidad Católica de Colombia',
    'ucb.br': 'Universidade Católica de Brasília',
    'ucb.edu.bo': 'Universidad Católica Boliviana, La Paz',
    'ucc.ie': 'University College Cork',
    'uccm.md': 'Moldova Cooperative Trade University',
    'uccs.edu': 'University of Colorado at Colorado Springs',
    'ucd.ie': 'University College Dublin',
    'ucdavis.edu': 'University of California, Davis',
    'ucdenver.edu': 'University of Colorado at Denver',
    'ucentral.edu.co': 'Universidad Central',
    'ucf.edu': 'University of Central Florida',
    'ucf.edu.cu': 'Universidad de Cienfuegos',
    'uchicago.edu': 'University of Chicago',
    'uchile.cl': 'Universidad de Chile',
    'uci.edu': 'University of California, Irvine',
    'ucl.ac.uk': 'University College London, University of London',
    'ucla.edu': 'University of California, Los Angeles',
    'ucla.edu.ve': 'Universidad Centro Occidental Lisandro Alvarado',
    'uclan.ac.uk': 'University of Central Lancashire',
    'uclm.es': 'Universidad de Castilla La Mancha',
    'uclouvain.be': 'Louvain School of Management',
    'uclv.edu.cu': 'Universidad Central de Las Villas',
    'ucm.cl': 'Universidad Catolica del Maule',
    'ucm.es': 'Universidad Complutense de Madrid',
    'ucmerced.edu': 'University of California, Merced',
    'ucmo.edu': 'University of Central Missouri',
    'ucn.cl': 'Universidad Catolica del Norte',
    'uco.edu': 'University of Central Oklahoma',
    'uco.edu.co': 'Universidad Católica del Oriente',
    'uconn.edu': 'University of Connecticut',
    'ucr.ac.cr': 'Universidad de Costa Rica',
    'ucr.edu': 'University of California, Riverside',
    'ucsal.br': 'Universidade Católica de Salvador',
    'ucsb.edu': 'University of California, Santa Barbara',
    'ucsc.edu': 'University of California, Santa Cruz',
    'ucsd.edu': 'University of California, San Diego',
    'ucsy.edu.mm': 'University of Computer Studies, Yangon',
    'uct.ac.za': 'University of Cape Town',
    'ucv.edu.ph': 'University of Cagayan Valley',
    'ucv.ve': 'Universidad Central de Venezuela',
    'ucy.ac.cy': 'University of Cyprus',
    'uda.ad': 'University of Andorra',
    'uda.cl': 'Universidad de Atacama',
    'udallas.edu': 'University of Dallas',
    'udayton.edu': 'University of Dayton',
    'udc.edu': 'University of the District of Columbia',
    'udc.es': 'Universidad de La Coruña',
    'udea.edu.co': 'Universidad de Antioquia',
    'udec.cl': 'Universidad de Concepcion',
    'udel.edu': 'University of Delaware',
    'udem.edu.co': 'Universidad de Medellín',
    'udem.edu.mx': 'Universidad de Monterrey',
    'udesa.edu.ar': 'Universidad de San Andres',
    'udesc.br': 'Universidade do Estado de Santa Catarina',
    'udg.co.cu': 'Universidad de Granma',
    'udg.mx': 'Universidad de Guadalajara',
    'udistrital.edu.co': 'Universidad Distral "Francisco José de Caldas"',
    'udlap.mx': 'Universidad de las Américas - Puebla',
    'udmercy.edu': 'University of Detroit Mercy',
    'udo.edu.ve': 'Universidad de Oriente',
    'udp.cl': 'Universidad Diego Portales',
    'udsm.ac.tz': 'University of Dar Es Salaam',
    'ue.edu.ph': 'University of the East, Coloocan',
    'uea.ac.uk': 'University of East Anglia',
    'uec.ac.jp': 'University of Electro-Communications',
    'uece.br': 'Universidade Estadual do Ceará',
    'uefs.br': 'Universidade Estadual de Feira de Santana',
    'uel.br': 'Universidade Estadual de Londrina',
    'uem.br': 'Universidade Estadual de Maringá',
    'uema.br': 'Universidade Estadual do Maranhão',
    'uepg.br': 'Universidade Estadual de Ponta Grossa',
    'uerj.br': 'Universidade do Estado do Rio de Janeiro',
    'uesb.br': 'Universidade Estadual Sudoeste da Bahia',
    'uesc.br': 'Universidade Estadual de Santa Cruz',
    'uespi.br': 'Universidade Estadual do Piauí',
    'uestc.edu.cn': 'University of Electronic Science and Technology of China',
    'uet.vnu.edu.vn': 'VNU University of Engineering and Technology',
    'uettaxila.edu.pk': 'University of Engineering and Technology Taxila',
    'uevora.pt': 'Universidade de Evora',
    'ufabc.edu.br': 'Universidade Federal do ABC',
    'ufba.br': 'Universidade Federal da Bahia',
    'ufc.br': 'Universidade Federal do Ceará',
    'ufcg.edu.br': 'Universidade Federal de Campina Grande',
    'ufes.br': 'Universidade Federal do Espírito Santo',
    'uff.br': 'Universidade Federal Fluminense',
    'ufg.br': 'Universidade Federal de Goiás',
    'ufjf.br': 'Universidade Federal de Juiz de Fora',
    'ufl.edu': 'University of Florida',
    'ufla.br': 'Universidade Federal de Lavras',
    'ufma.br': 'Universidade Federal do Maranhão',
    'ufmg.br': 'Universidade Federal de Minas Gerais',
    'ufms.br': 'Universidade Federal de Mato Grosso do Sul',
    'ufmt.br': 'Universidade Federal de Mato Grosso',
    'ufop.br': 'Universidade Federal de Ouro Preto',
    'ufpa.br': 'Universidade Federal do Pará',
    'ufpb.br': 'Universidade Federal da Paraíba',
    'ufpe.br': 'Universidade Federal de Pernambuco',
    'ufpi.br': 'Universidade Federal do Piauí',
    'ufpr.br': 'Universidade Federal do Paraná',
    'ufps.edu.co': 'Universidad Francisco de Paula Santander',
    'ufrgs.br': 'Universidade Federal do Rio Grande do Sul',
    'ufrj.br': 'Universidade Federal do Rio de Janeiro',
    'ufrn.br': 'Universidade Federal do Rio Grande do Norte',
    'ufro.cl': 'Universidad de La Frontera',
    'ufs.br': 'Universidade Federal de Sergipe',
    'ufsc.br': 'Universidade Federal de Santa Catarina',
    'ufscar.br': 'Universidade Federal de São Carlos',
    'ufsm.br': 'Universidade Federal de Santa Maria',
    'uftm.edu.br': 'Universidade Federal do Triângulo Mineiro',
    'ufu.br': 'Universidade Federal de Uberlândia',
    'ufv.br': 'Universidade Federal de Viçosa',
    'ug.edu.gh': 'University of Ghana',
    'uga.edu': 'University of Georgia',
    'ugal.ro': 'University of Galatzi',
    'ugatu.ac.ru': 'Ufa State Aviation Technical University',
    'ugb.edu.sv': 'Universidad Capitain General Gerardo Barrios',
    'ugent.be': 'Universiteit Gent',
    'ugm.ac.id': 'Universitas Gadjah Mada',
    'ugr.es': 'Universidad de Granada',
    'ugto.mx': 'Universidad de Guanajuato',
    'uh.cu': 'Universidad de La Habana',
    'uh.edu': 'University of Houston',
    'uhd.edu': 'University of Houston-Downtown',
    'uhd.edu.iq': 'University of Human Development (Kurdistan Region)',
    'uho.edu.cu': 'Universidad de Holguín',
    'ui.ac.id': 'Universitas Indonesia',
    'ui.ac.ir': 'Isfahan University',
    'ui.edu.ng': 'University of Ibadan',
    'uib.no': 'University of Bergen',
    'uic.edu': 'University of Illinois at Chicago',
    'uidaho.edu': 'University of Idaho',
    'uii.ac.id': 'Universitas Islam Indonesia',
    'uinjkt.ac.id': 'Universitas Islam Jakarta',
    'uio.no': 'University of Oslo',
    'uiowa.edu': 'University of Iowa',
    'uis.edu': 'University of Illinois at Springfield',
    'uis.edu.co': 'Universidad Industrial de Santander',
    'uis.no': 'University of Stavanger',
    'uit.no': 'University of Tromsø',
    'uitm.edu.my': 'Universiti Teknologi Mara',
    'uits.edu.bd': 'University of Information Technology & Sciences',
    'uiu.ac.bd': 'United International University',
    'uiu.edu': 'Upper Iowa University',
    'uj.ac.za': 'University of Johannesburg',
    'uj.edu.pl': 'Jagiellonian University Cracow',
    'ujat.mx': 'Universidad Juárez Autónoma de Tabasco',
    'uji.es': 'Universitat Jaume I de Castellón',
    'ujn.edu.cn': 'University of Jinan',
    'uk.ac.ir': 'Shahid Bahonar University of Kerman',
    'ukdw.ac.id': 'Universitas Kristen Duta Wacana',
    'ukim.edu.mk': 'St.Cyril and Methodius University',
    'ukm.my': 'Universiti Kebangsaan Malaysia',
    'uksw.edu': 'Universitas Kristen Satya Wacana',
    'uktech.ac.in': 'Uttarakhand Technical University',
    'uky.edu': 'University of Kentucky',
    'ul.edu.lb': 'Lebanese University',
    'ul.ie': 'University of Limerick',
    'ula.ve': 'Universidad de Los Andes',
    'ulaval.ca': 'Université Laval',
    'ulb.ac.be': 'Université Libre de Bruxelles',
    'ulbra.br': 'Universidade Luterana do Brasil',
    'ulbsibiu.ro': 'University Lucian Blaga of Sibiu',
    'uleth.ca': 'University of Lethbridge',
    'uliege.be': 'University of Liège',
    'ull.es': 'Universidad de La Laguna',
    'ulm.edu': 'University of Louisiana at Monroe',
    'ulpgc.es': 'Universidad de Las Palmas de Gran Canaria',
    'ulstu.ru': 'Ulyanovsk State Technical University',
    'ulsu.ru': 'Ulyanovsk State University',
    'uludag.edu.tr': 'Uludag University',
    'um.ac.id': 'Universitas Negeri Malang',
    'um.ac.ir': 'Ferdowsi University of Mashhad',
    'um.edu.mt': 'University of Malta',
    'um.edu.my': 'Universiti Malaya',
    'um.es': 'Universidad de Murcia',
    'um.rnu.tn': 'Université de Monastir',
    'um.si': 'University of Maribor',
    'uma.es': 'Universidad de Málaga',
    'umag.cl': 'Universidad de Magallanes',
    'umaine.edu': 'University of Maine',
    'umanitoba.ca': 'University of Manitoba',
    'umass.edu': 'University of Massachusetts at Amherst',
    'umassd.edu': 'University of Massachusetts at Dartmouth',
    'umayor.cl': 'Universidad Mayor',
    'umb.edu': 'University of Massachusetts Boston',
    'umb.sk': 'Matej Bel University in Banská Bystrica',
    'umbc.edu': 'University of Maryland, Baltimore County',
    'umcc.cu': 'Universidad de Matanzas Camilo Cienfuegos',
    'umd.edu': 'University of Maryland, College Park',
    'umdearborn.edu': 'University of Michigan - Dearborn',
    'umflint.edu': 'University of Michigan-Flint',
    'umg.edu.gt': 'Universidad Mariano Gálvez',
    'umich.edu': 'University of Michigan - Ann Arbor',
    'uminho.pt': 'Universidade do Minho',
    'umkc.edu': 'University of Missouri - Kansas City',
    'uml.edu': 'University of Massachusetts at Lowell',
    'umm.ac.id': 'Universitas Muhammadiyah Malang',
    'umn.edu': 'University of Minnesota',
    'umoncton.ca': 'University of Moncton',
    'umontreal.ca': 'Université de Montréal',
    'ump.ac.za': 'Univerisity of Mpumalanga',
    'umpqua.edu': 'Umpqua Community College',
    'ums.ac.id': 'Universitas Muhammadiyah Surakarta',
    'umsl.edu': 'University of Missouri - Saint Louis',
    'umss.edu.bo': 'Universidad Mayor de San Simón',
    'umt.edu': 'University of Montana',
    'umt.edu.pk': 'University of Management and Technology',
    'umu.se': 'Umea University',
    'umw.edu': 'University of Mary Washington',
    'una.ac.cr': 'Universidad Nacional',
    'una.edu': 'University of North Alabama',
    'una.py': 'Universidad Nacional de Asunción',
    'unaab.edu.ng': 'University of Agriculture Abeokuta',
    'unab.cl': 'Universidad Nacional Andrés Bello',
    'unair.ac.id': 'Universitas Airlangga',
    'unak.is': 'University of Akureyri',
    'unal.edu.co': 'Universidad Nacional de Colombia',
    'unam.mx': 'Universidad Nacional Autónoma de México',
    'unan.edu.ni': 'Universidad Nacional Autonoma de Nicaragua',
    'unap.edu.pe': 'Universidad Nacional del Altiplano',
    'unapec.edu.do': 'Universidad APEC',
    'unb.br': 'Universidade de Brasília',
    'unb.ca': 'University of New Brunswick',
    'unbc.ca': 'University of Northern British Columbia',
    'unbi.ba': 'University of Bihac',
    'unc.edu': 'University of North Carolina at Chapel Hill',
    'unc.edu.ar': 'Universidad Nacional de Córdoba',
    'unc.edu.pe': 'Universidad Nacional de Cajamarca',
    'unc.edu.ph': 'University of Nueva Caceres',
    'unca.edu': 'University of North Carolina at Asheville',
    'uncc.edu': 'University of North Carolina at Charlotte',
    'uncfsu.edu': 'Fayetteville State University',
    'uncg.edu': 'University of North Carolina at Greensboro',
    'unco.edu': 'University of Northern Colorado',
    'uncw.edu': 'University of North Carolina at Wilmington',
    'und.edu': 'University of North Dakota',
    'undip.ac.id': 'Universitas Diponegoro',
    'une.edu.mx': 'Universidad del Noreste',
    'une.edu.ve': 'Universidad Nueva Esparta',
    'unec.edu.az': 'Azerbaijan State University of Economics',
    'uned.es': 'Universidad Nacional de Educación a Distancia',
    'unefa.edu.ve': 'Universidad Nacional Experimental de la Fuerza Armada',
    'uneg.edu.ve': 'Universidad Nacional Experimental de Guayana',
    'unesa.ac.id': 'Universitas Negeri Surabaya',
    'unesp.br': 'Universidade Estadual Paulista',
    'unet.edu.ve': 'Universidad Nacional Experimental del Táchira',
    'unf.edu': 'University of North Florida',
    'ung.edu': 'University of North Georgia',
    'unh.edu': 'University of New Hampshire, Durham',
    'unhas.ac.id': 'Universitas Hasanuddin',
    'uni-augsburg.de': 'Universität Augsburg',
    'uni-bamberg.de': 'Otto-Friedrich Universität Bamberg',
    'uni-bayreuth.de': 'Universität Bayreuth',
    'uni-bge.hu': 'Budapest Business School',
    'uni-bonn.de': 'Rheinische Friedrich-Wilhelms Universität Bonn',
    'uni-bremen.de': 'Universität Bremen',
    'uni-dubna.ru': 'Dubna International University for Nature, Society and Man',
    'uni-freiburg.de': 'Albert-Ludwigs-Universität Freiburg',
    'uni-goettingen.de': 'Georg-August Universität Göttingen',
    'uni-halle.de': 'Martin-Luther Universität Halle-Wittenberg',
    'uni-hamburg.de': 'Universität Hamburg',
    'uni-heidelberg.de': 'Ruprecht-Karls-Universität Heidelberg',
    'uni-jena.de': 'Friedrich-Schiller Universität Jena',
    'uni-kassel.de': 'Universität Kassel',
    'uni-kiel.de': 'Christian-Albrechts-Universität Kiel',
    'uni-kl.de': 'Universität Kaiserslautern',
    'uni-leipzig.de': 'Universität Leipzig',
    'uni-lj.si': 'University of Ljubljana',
    'uni-mainz.de': 'Johannes-Gutenberg Universität Mainz',
    'uni-marburg.de': 'Phillips-Universität Marburg',
    'uni-miskolc.hu': 'University of Miskolc',
    'uni-muenchen.de': 'Ludwig-Maximilians-Universität München',
    'uni-muenster.de': 'Westfälische Wilhelms-Universität Münster',
    'uni-mysore.ac.in': 'University of Mysore',
    'uni-obuda.hu': 'Óbuda University',
    'uni-paderborn.de': 'Universität Paderborn',
    'uni-passau.de': 'Universität Passau',
    'uni-plovdiv.bg': 'University of Plovdiv',
    'uni-potsdam.de': 'Universität Potsdam',
    'uni-pr.edu': 'University of Prishtina',
    'uni-regensburg.de': 'Universität Regensburg',
    'uni-rostock.de': 'Universität Rostock',
    'uni-saarland.de': 'Universität des Saarlandes',
    'uni-sofia.bg': 'Sofia University "St. Kliment Ohridski"',
    'uni-stuttgart.de': 'Universität Stuttgart',
    'uni-tuebingen.de': 'Eberhard-Karls-Universität Tübingen',
    'uni-ulm.de': 'Universität Ulm',
    'uni-wuppertal.de': 'Bergische Universität Gesamthochschule Wuppertal',
    'uni.edu': 'University of Northern Iowa',
    'uni.edu.ni': 'Universidad Nacional de Ingenieria',
    'uni.edu.pe': 'Universidad Nacional de Ingeniería',
    'uni.lu': 'University of Luxemburg',
    'uni.wroc.pl': 'University of Wroclaw',
    'uniandes.edu.co': 'Universidad de Los Andes',
    'uniba.it': 'University of Bari',
    'uniba.sk': 'Comenius University in Bratislava',
    'unibas.it': 'Basilicata University Potenza',
    'unibe.edu.do': 'Universidad Iberoamericana',
    'uniben.edu': 'University of Benin',
    'unibg.it': 'University of Bergamo',
    'unibl.org': 'University of Banja Luka',
    'unibo.it': 'University of Bologna',
    'unibs.it': 'University of Brescia',
    'unibuc.ro': 'University of Bucharest',
    'unica.cu': 'Universidad de Ciego de Avila',
    'unica.it': 'University of Cagliari',
    'unical.it': 'University of Calabria',
    'unicam.it': 'University of Camerino',
    'unicamp.br': 'Universidade Estadual de Campinas',
    'unicap.br': 'Universidade Católica de Pernambuco',
    'unicas.it': 'University of Cassino',
    'unicen.edu.ar': 'Universidad Nacional del Centro de la Provincia de Buenos '
                    'Aires',
    'unich.it': 'University of Chieti',
    'unict.it': 'University of Catania',
    'unideb.hu': 'University of Debrecen',
    'unifacs.br': 'Universidade Salvador',
    'unife.it': 'University of Ferrara',
    'unifei.edu.br': 'Universidade Federal de Itajubá',
    'unifeso.edu.br': 'Centro Universitário Serra dos Órgãos',
    'unifg.it': 'University of Foggia',
    'unifi.it': 'University of Florence',
    'unifiji.ac.fj': 'University of Fiji',
    'unifor.br': 'Universidade de Fortaleza',
    'unige.ch': 'University of Geneva',
    'unige.it': 'University of Genoa',
    'unigoa.ac.in': 'Goa University',
    'unijos.edu.ng': 'University of Jos',
    'unika.ac.id': 'Universitas Katolik Soegijapranoto',
    'unikin.cd': 'Université de Kinshasa',
    'unikl.edu.my': 'Universiti Kuala Lumpur',
    'unikom.ac.id': 'Universitas Komputer Indonesia',
    'unilag.edu.ng': 'University of Lagos',
    'unilim.fr': 'Université de Limoges',
    'unilus.ac.zm': 'University of Lusaka',
    'unima.mw': 'University of Malawi | Old',
    'unimc.it': 'University of Macerata',
    'unime.it': 'University of Messina',
    'unimelb.edu.au': 'University of Melbourne',
    'unimet.edu.ve': 'Universidad Metropolitana',
    'unimi.it': 'University of Milan',
    'unimib.it': 'University of Milan - Bicocca',
    'unimol.it': 'University of Molise',
    'unina.it': 'University of Naples Federico II',
    'unine.ch': 'Université de Neuchâtel',
    'uninorte.edu.co': 'Universidad del Norte',
    'uninove.br': 'UNINOVE',
    'uninsubria.it': 'University of Insubria',
    'unioeste.br': 'Universidade Estadual do Oeste do Paraná',
    'union.edu': 'Union College',
    'unipa.it': 'University of Palermo',
    'unipd.it': 'University of Padua',
    'unipg.it': 'University of Perugia',
    'unipi.gr': 'University of Piraeus',
    'unipi.it': 'University of Pisa',
    'unipiloto.edu.co': 'Universidad Piloto de Colombia',
    'unipr.it': 'University of Parma',
    'unipv.it': 'University of Pavia',
    'uniquindio.edu.co': 'Universidad del Quindío',
    'unirc.it': 'University of Reggio Calabria',
    'uniri.hr': 'University of Rijeka',
    'uniroma1.it': 'University of Roma "La Sapienza"',
    'uniroma3.it': 'Third University of Rome',
    'unirsm.sm': 'University of San Marino',
    'unisa.ac.za': 'University of South Africa',
    'unisa.br': 'Universidade de Santo Amaro',
    'unisa.it': 'University of Salerno',
    'unisannio.it': 'University of Sannio',
    'unisc.br': 'Universidade de Santa Cruz do Sul',
    'unishivaji.ac.in': 'Shivaji University',
    'unisi.it': 'University of Siena',
    'unisinos.br': 'Universidade Vale do Rio dos Sinos',
    'uniss.it': 'University of Sassari',
    'unist.ac.kr': 'Ulsan National Institute of Science and Technology',
    'unist.hr': 'University of Split',
    'unistra.fr': 'Université de Strasbourg',
    'unistrapg.it': 'University of Italian Studies for Foreigners of Perugia',
    'unistrasi.it': 'University of Italian Studies for Foreigners of Siena',
    'unisul.br': 'Universidade do Sul de Santa Catarina',
    'unit.br': 'Universidade Tiradentes',
    'unitau.br': 'Universidade de Taubaté',
    'unitbv.ro': 'University "Transilvany" of Brasov',
    'unite.it': 'University of Teramo',
    'unitec.edu': 'Universidad Tecnológica Centroamericana',
    'unitec.mx': 'Universidad Tecnológica de México',
    'uniten.edu.my': 'Universiti Tenaga Nasional',
    'unitir.edu.al': 'University of Tirana',
    'unitn.it': 'University of Trento',
    'unito.it': 'University of Turin',
    'unitru.edu.pe': 'Universidad Nacional de La Libertad, Trujillo',
    'units.it': 'University of Trieste',
    'unitus.it': 'Viterbo State University',
    'uniud.it': 'University of Udine',
    'uniurb.it': 'University of Urbino',
    'univ-amu.fr': "Université d'Aix-Marseille",
    'univ-annaba.dz': 'Université Badji Mokhtar',
    'univ-antananarivo.mg': "Université d'Antananarivo",
    'univ-biskra.dz': 'Université de Biskra',
    'univ-blida.dz': 'Université de Blida',
    'univ-grenoble-alpes.fr': 'Université Grenoble Alpes',
    'univ-kag.org': 'Université Kofi Annan',
    'univ-lehavre.fr': 'Université du Havre',
    'univ-lille1.fr': 'Université des Sciences et Technologies de Lille (Lille I)',
    'univ-littoral.fr': "Université du Littoral Cote d'Opale",
    'univ-lome.tg': 'Université de Lomé',
    'univ-lorraine.fr': 'Université de Lorraine',
    'univ-nantes.fr': 'Université de Nantes',
    'univ-ndjamena.org': "Université de N'Djamena",
    'univ-ovidius.ro': 'University of Constanta',
    'univ-paris1.fr': 'Université Panthéon-Sorbonne (Paris I)',
    'univ-paris13.fr': 'Université Paris Nord (Paris XIII)',
    'univ-pau.fr': "Université de Pau et des Pays de l'Adour",
    'univ-rennes1.fr': 'Université Rennes I',
    'univ-rouen.fr': 'Université de Rouen - Haute Normandie',
    'univ-setif.dz': 'Université de Sétif',
    'univ-skikda.dz': 'Université de Skikda',
    'univ-tlemcen.dz': 'Université Abou Bekr Belkaid, Tlemcen',
    'univ-tours.fr': 'Université François Rabelais de Tours',
    'univ.kiev.ua': 'Taras Shevchenko National University of Kyiv',
    'univalle.edu': 'Universidad Privada del Valle',
    'univalle.edu.co': 'Universidad del Valle del Cauca',
    'univap.br': 'Universidade Vale do Paraiba',
    'univaq.it': 'University of Aquila',
    'unive.it': 'University of Venice',
    'univer.kharkov.ua': 'Kharkiv National University',
    'univgb.rnu.tn': 'Université de Gabès',
    'univie.ac.at': 'Universität Vienna',
    'univr.it': 'University of Verona',
    'uniyar.ac.ru': 'Yaroslavl State University',
    'uniza.sk': 'University of Zilinska',
    'unizg.hr': 'University of Zagreb',
    'unja.ac.id': 'Universitas Jambi',
    'unjfsc.edu.pe': 'Universidad Nacional José Faustino Sánchez Carrión',
    'unju.edu.ar': 'Universidad Nacional de Jujuy',
    'unk.edu': 'University of Nebraska, Kearney',
    'unl.edu': 'University of Nebraska, Lincoln',
    'unl.pt': 'Universidade Nova de Lisboa',
    'unlam.ac.id': 'Universitas Lambung Mangkurat',
    'unlam.edu.ar': 'Universidad Nacional de La Matanza',
    'unlar.edu.ar': 'Universidad Nacional de La Rioja',
    'unlp.edu.ar': 'Universidad Nacional de La Plata',
    'unlv.edu': 'University of Nevada, Las Vegas',
    'unm.edu': 'University of New Mexico',
    'unmo.ba': 'Univerzitet u Mostaru "Dzemal Bijedic"',
    'unmsm.edu.pe': 'Universidad Nacional Mayor de San Marcos',
    'unn.edu.ng': 'University of Nigeria',
    'unnes.ac.id': 'Universitas Negeri Semarang',
    'uno-r.edu.ph': 'University of Negros Occidental-Recoletos',
    'uno.edu': 'University of New Orleans',
    'unoesc.edu.br': 'Universidade do Oeste de Santa Catarina',
    'unoeste.br': 'Universidade do Oeste Paulista',
    'unom.ac.in': 'University of Madras',
    'unomaha.edu': 'University of Nebraska, Omaha',
    'unp.edu.ar': 'Universidad Nacional de la Patagonia "San Juan Bosco"',
    'unpa.edu.ar': 'Universidad Nacional de la Patagonia Austral',
    'unpad.ac.id': 'Universitas Padjadjaran',
    'unpar.ac.id': 'Universitas Katolik Parahyangan',
    'unq.edu.ar': 'Universidad Nacional de Quilmes',
    'unr.edu': 'University of Nevada, Reno',
    'unr.edu.ar': 'Universidad Nacional de Rosario',
    'uns.ac.id': 'Universitas Sebelas Maret',
    'uns.ac.rs': 'University of Novi Sad',
    'uns.edu.ar': 'Universidad Nacional del Sur',
    'unsa.ba': 'University of Sarajevo',
    'unsa.edu.pe': 'Universidad Nacional de San Agustin',
    'unsaac.edu.pe': 'Universidad Nacional de San Antonio Abad',
    'unse.edu.ar': 'Universidad Nacional de Santiago del Estero',
    'unsl.edu.ar': 'Universidad Nacional de San Luis',
    'unsri.ac.id': 'Universitas Sriwijaya',
    'unsw.edu.au': 'University of New South Wales',
    'unsyiah.ac.id': 'Universitas Syiah Kuala',
    'unt.edu': 'University of North Texas',
    'untan.ac.id': 'Universitas Tanjungpura',
    'untar.ac.id': 'Universitas Tarumanagara',
    'untz.ba': 'University of Tuzla',
    'unu.edu.pe': 'Universidad Nacional de Ucayali',
    'unud.ac.id': 'Universitas Udayana',
    'uny.ac.id': 'Universitas Negeri Yogyakarta',
    'unza.zm': 'University of Zambia',
    'uo.edu.cu': 'Universidad de Oriente',
    'uoa.gr': 'University of Athens',
    'uoanbar.edu.iq': 'University of Anbar',
    'uob.edu.bh': 'University of Bahrain',
    'uobabylon.edu.iq': 'Uinversity of Babylon',
    'uobaghdad.edu.iq': 'University of Baghdad',
    'uobasrah.edu.iq': 'University of Basrah',
    'uoc.gr': 'University of Crete',
    'uod.ac': 'University of Dohuk (Kurdistan Region)',
    'uoda.edu.bd': 'University of Development Alternative',
    'uodiyala.edu.iq': 'Diyala University',
    'uog.edu.gy': 'University of Guyana',
    'uoguelph.ca': 'University of Guelph',
    'uoh.edu.sa': 'University of Hail',
    'uok.ac.ir': 'University of Kurdistan',
    'uok.edu.pk': 'University of Karachi',
    'uokerbala.edu.iq': 'Kerbala University',
    'uokirkuk.edu.iq': 'University of Kirkuk',
    'uokufa.edu.iq': 'University of Kufa',
    'uol.de': 'Carl von Ossietzky Universität Oldenburg',
    'uom.ac.mu': 'University of Mauritius',
    'uom.gr': 'University of Macedonia',
    'uomisan.edu.iq': 'Misan University',
    'uomosul.edu.iq': 'University of Mosul',
    'uomustansiriyah.edu.iq': 'University of Mustansiriyah',
    'uonbi.ac.ke': 'University of Nairobi',
    'uop.edu.jo': 'University of Petra',
    'uopeople.edu': 'University of the People',
    'uoradea.ro': 'University of Oradea',
    'uoregon.edu': 'University of Oregon',
    'uos.ac.kr': 'Seoul City University',
    'uot.edu.ly': 'University of Tripoli',
    'uotechnology.edu.iq': 'University of Technology - Iraq',
    'uottawa.ca': 'University of Ottawa',
    'uow.edu.au': 'University of Wollongong',
    'uowasit.edu.iq': 'University of Wassit',
    'uowdubai.ac.ae': 'University of Wollongong - Dubai Campus',
    'up.ac.za': 'University of Pretoria',
    'up.edu': 'University of Portland',
    'up.pt': 'Universidade do Porto',
    'upao.edu.pe': 'Universidad Privada Antenor Orrego',
    'upatras.gr': 'University of Patras',
    'upb.edu': 'Universidad Privada Boliviana',
    'upb.edu.co': 'Universidad Pontificia Bolivariana',
    'upb.edu.ph': 'University of the Philippines Baguio',
    'upc.edu': 'Universidad Politécnica de Cataluna',
    'upc.edu.pe': 'Universidad Peruana de Ciencias Aplicadas',
    'upd.edu.ph': 'University of the Philippines Diliman',
    'upds.edu.bo': 'Universidad Domingo Savio',
    'upe.br': 'Universidade de Pernambuco',
    'upei.ca': 'University of Prince Edward Island',
    'upenn.edu': 'University of Pennsylvania',
    'upes.ac.in': 'University of Petroleum and Energy Studies',
    'upeu.edu.pe': 'Universidad Peruana Union',
    'upf.edu': 'Universitat Pompeu Fabra',
    'upg-ploiesti.ro': 'University Oil- Gas Ploiesti',
    'uph.edu': 'Universitas Pelita Harapan',
    'upit.ro': 'University of Pitesti',
    'upjs.sk': 'Pavol Jozef Safarik University in Kosice',
    'uplb.edu.ph': 'University of the Philippines Los Banos',
    'upm.es': 'Universidad Politécnica de Madrid',
    'upmc.fr': 'Sorbonne Université - Faculté des Sciences (Paris VI)',
    'upol.cz': 'Palacký University Olomouc',
    'upr.edu': 'University of Puerto Rico',
    'upr.edu.cu': 'Universidad de Pinar del Río',
    'upr.si': 'University of Primorska',
    'upsa.edu.bo': 'Universidad Privada de Santa Cruz de la Sierra',
    'upt.ro': 'Polytechnic University of Timisoara',
    'uptc.edu.co': 'Universidad Pedagógica y Tecnológica de Colombia',
    'upv.edu.ph': 'University of the Philippines Visayas',
    'upv.es': 'Universidad Politécnica de Valencia',
    'uq.edu.au': 'University of Queensland',
    'uqo.ca': 'Université du Québec en Outaouais',
    'uqu.edu.sa': 'Umm Al-Qura University',
    'urbe.edu': 'Universidad Dr. Rafael Belloso Chacín',
    'uregina.ca': 'Campion College',
    'urfu.ru': 'Ural Federal University',
    'uri.br': 'Universidade Regional Integrada do Alto Uruguai e das Missões',
    'uri.edu': 'University of Rhode Island',
    'urjc.es': 'Universidad Rey Juan Carlos',
    'url.edu.gt': 'Universidad Rafael Landívar',
    'urmia.ac.ir': 'Urmia University',
    'uru.edu': 'Universidad Rafael Urdaneta',
    'us.edu.pl': 'University of Silesia',
    'us.es': 'Universidad de Sevilla',
    'usa.edu.pk': 'University of South Asia',
    'usac.edu.gt': 'Universidad de San Carlos de Guatemala',
    'usach.cl': 'Universidad de Santiago de Chile',
    'usafa.af.mil': 'United States Air Force Academy',
    'usal.es': 'Universidad de Salamanca',
    'usask.ca': 'University of Saskatchewan',
    'usb.ve': 'Universidad Simón Bolivar',
    'usc.ac.ir': 'University of Science and Culture',
    'usc.edu': 'University of Southern California',
    'usc.edu.cn': 'South China University',
    'uscga.edu': 'United States Coast Guard Academy',
    'usd.edu': 'University of South Dakota',
    'usergioarboleda.edu.co': 'Universidad Sergio Arboleda',
    'usf.edu': 'University of South Florida',
    'usfca.edu': 'University of San Francisco',
    'usi.ch': 'Universita della Svizzera Italiana',
    'usiu.ac.ke': 'United States International University',
    'usm.edu': 'University of Southern Mississippi',
    'usm.my': 'Universiti Sains Malaysia',
    'usmba.ac.ma': 'Université Sidi Mohammed Ben Abdellah',
    'usna.edu': 'United States Naval Academy',
    'usp.br': 'Universidade de São Paulo',
    'usst.edu.cn': 'Shanghai University of Science and Technology',
    'ust.edu.ph': 'University of Santo Tomas',
    'ust.hk': 'Hong Kong University of Science and Technology',
    'usta.edu.co': 'Universidad Santo Tomás',
    'ustc.ac.bd': 'University of Science & Technology Chittagong',
    'ustc.edu.cn': 'University of Science and Technology of China',
    'usthb.dz': 'Université des Sciences et de la Technologie Houari Boumediène',
    'ustmb.ac.ir': 'Mazandaran University of Science & Technology',
    'usu.ac.id': 'Universitas Sumatera Utara',
    'usu.edu': 'Utah State University',
    'usv.ro': 'University of Suceava',
    'ut.ac.id': 'Universitas Terbuka Indonesia',
    'ut.ac.ir': 'University of Tehran',
    'ut.ee': 'University of Tartu',
    'uta.edu': 'University of Texas at Arlington',
    'uta.fi': 'University of Tampere',
    'utadeo.edu.co': 'Universidad de Bogotá "Jorge Tadeo Lozano"',
    'utah.edu': 'University of Utah',
    'utahtech.edu': 'Utah Tech University',
    'utalca.cl': 'Universidad de Talca',
    'utar.edu.my': 'Tunku Abdul Rahman University (Chinese University)',
    'utas.edu.au': 'University of Tasmania',
    'utb.cz': 'Tomas Bata University in Zlin',
    'utb.edu': 'University of Texas at Brownsville',
    'utc.edu': 'University of Tennessee at Chattanooga',
    'utc.fr': 'Université de Technologie de Compiègne',
    'utcluj.ro': 'Technical University of Cluj-Napoca',
    'utdallas.edu': 'University of Texas at Dallas',
    'utech.edu.jm': 'University of Technology Jamaica',
    'utep.edu': 'University of Texas at El Paso',
    'utesa.edu': 'Universidad Tecnológica de Santiago',
    'utexas.edu': 'University of Texas at Austin',
    'utfpr.edu.br': 'Universidade Tecnológica Federal do Paraná',
    'utg.edu.gm': 'University of the Gambia',
    'utk.edu': 'University of Tennessee, Knoxville',
    'utm.edu': 'University of Tennessee, Martin',
    'utm.md': 'Moldova Technical University',
    'utm.mx': 'Universidad Tecnologica de la Mixteca',
    'utm.my': 'Universiti Teknologi Malaysia',
    'utm.rnu.tn': 'Université de Tunis El Manar',
    'utmn.ru': 'Tyumen State University',
    'utn.edu.ar': 'Universidad Tecnológica Nacional',
    'uto.edu.bo': 'Universidad Técnica de Oruro',
    'utoledo.edu': 'University of Toledo',
    'utoronto.ca': "University of St. Michael's College",
    'utp.edu.co': 'Universidad Tecnológica de Pereira',
    'utp.edu.my': 'Petronas Technology University',
    'utpb.edu': 'University of Texas Permian Basin',
    'utrgv.edu': 'University of Texas Rio Grande Valley',
    'uts.edu.au': 'University of Technology Sydney',
    'utsa.edu': 'University of Texas at San Antonio',
    'utt.fr': 'Université de Technologie de Troyes',
    'uttyler.edu': 'University of Texas at Tyler',
    'utulsa.edu': 'University of Tulsa',
    'utwente.nl': 'University of Twente',
    'uu.edu': 'Union University',
    'uu.nl': 'Utrecht University',
    'uu.se': 'Uppsala University',
    'uum.edu.my': 'Universiti Utara Malaysia',
    'uut.ac.ir': 'Urmia University of Technology',
    'uv.mx': 'Universidad Veracruzana',
    'uva.br': 'Universidade Veiga de Almeida',
    'uva.es': 'Universidad de Valladolid',
    'uva.nl': 'University of Amsterdam',
    'uvi.edu': 'University of the Virgin Islands',
    'uvic.ca': 'University of Victoria',
    'uvt.ro': 'West University of Timisoara',
    'uvu.edu': 'Utah Valley Uniersity',
    'uw.edu.pl': 'University of Warsaw',
    'uwa.edu.au': 'University of Western Australia',
    'uwaterloo.ca': 'University of Waterloo',
    'uwc.ac.za': 'University of the Western Cape',
    'uwc.edu': 'University of Wisconsin Colleges',
    'uwec.edu': 'University of Wisconsin - Eau Claire',
    'uwed.uz': 'University of World Economy and Diplomacy',
    'uwf.edu': 'University of West Florida',
    'uwindsor.ca': 'University of Windsor',
    'uwinnipeg.ca': 'University of Winnipeg',
    'uwlax.edu': 'University of Wisconsin - LaCrosse',
    'uwm.edu': 'University of Wisconsin - Milwaukee',
    'uwm.edu.pl': 'University of Wamia and Masuria in Olsztyn',
    'uwo.ca': 'Brescia University College',
    'uwosh.edu': 'University of Wisconsin - Oshkosh',
    'uwp.edu': 'University of Wisconsin - Parkside',
    'uwplatt.edu': 'University of Wisconsin - Platteville',
    'uwrf.edu': 'University of Wisconsin - River Falls',
    'uwsp.edu': 'University of Wisconsin - Stevens Point',
    'uwstout.edu': 'University of Wisconsin - Stout',
    'uwsuper.edu': 'University of Wisconsin - Superior',
    'uww.edu': 'University of Wisconsin - Whitewater',
    'uwyo.edu': 'University of Wyoming',
    'uy1.uninet.cm': 'Université de Yaoundé I',
    'uzh.ch': 'Universität Zürich',
    'va.lv': 'Vidzeme University College',
    'valdosta.edu': 'Valdosta State University',
    'valenciacollege.edu': 'Valencia College',
    'valpo.edu': 'Valparaiso University',
    'vanderbilt.edu': 'Vanderbilt University',
    'vassar.edu': 'Vassar College',
    'vcu.edu': 'Virginia Commonwealth University',
    'vgtu.lt': 'Vilnius Gediminas Technical University',
    'vgu.edu.vn': 'Vietnamese - German University',
    'villanova.edu': 'Villanova University',
    'vimaru.edu.vn': 'Vietnam Maritime University',
    'virginia.edu': 'University of Virginia, Charlottesville',
    'vistula.edu.pl': 'Vistula University',
    'vit.ac.in': 'Vellore Institute of Technology',
    'vitbhopal.ac.in': 'VIT Bhopal',
    'vkgu.kz': 'East Kazakhstan State University',
    'vlsu.ru': 'Vladimir State University',
    'vnu.edu.vn': 'Vietnam National University Hanoi',
    'vnuhcm.edu.vn': 'Vietnam National University Ho Chi Minh City',
    'voenmeh.ru': 'Baltic State Technical University',
    'volsu.ru': 'Volgograd State University',
    'vsb.cz': 'Technical University of Mining and Metallurgy Ostrava',
    'vssut.ac.in': 'Veer Surendra Sai University of Technology',
    'vstu.ru': 'Volgograd State Technical University',
    'vsu.by': 'Vitebsk State University',
    'vsu.edu': 'Virginia State University',
    'vsu.ru': 'Voronezh State University',
    'vt.edu': 'Virginia Polytechnic Institute and State University',
    'vtu.ac.in': 'Visvesvaraya Technological University',
    'vu.edu.au': 'Victoria University',
    'vu.edu.pk': 'Virtual University of Pakistan',
    'vu.lt': 'Vilnius University',
    'vu.nl': 'Vrije Universiteit Amsterdam',
    'vutbr.cz': 'Brno University of Technology',
    'vvsu.ru': 'Vladivostock State University of Economics',
    'wagner.edu': 'Wagner College',
    'waikato.ac.nz': 'University of Waikato',
    'wakayama-u.ac.jp': 'Wakayama University',
    'wallace.edu': 'George C Wallace State Community College-\u200bDothan',
    'warwick.ac.uk': 'University of Warwick',
    'washcoll.edu': 'Washington College',
    'washington.edu': 'University of Washington',
    'washjeff.edu': 'Washington & Jefferson College',
    'wayne.edu': 'Wayne State University',
    'wcupa.edu': 'West Chester University of Pennsylvania',
    'weber.edu': 'Weber State University',
    'webster.edu': 'Webster University',
    'wellesley.edu': 'Wellesley College',
    'western.edu': 'Western State Colorado University',
    'westga.edu': 'West Georgia College',
    'westminster.ac.uk': 'University of Westminster',
    'westminster.edu': 'Westminster College',
    'westmont.edu': 'Westmont College',
    'wfu.edu': 'Wake Forest University',
    'wgu.edu': 'Western Governors University',
    'wheaton.edu': 'Wheaton College',
    'whitman.edu': 'Whitman College',
    'whitworth.edu': 'Whitworth College',
    'whu.edu.cn': 'Wuhan University',
    'whut.edu.cn': 'Wuhan University of Technology',
    'wichita.edu': 'Wichita State University',
    'wilkes.edu': 'Wilkes University',
    'willamette.edu': 'Willamette University',
    'winona.edu': 'Winona State University',
    'winthrop.edu': 'Winthrop University',
    'wisc.edu': 'University of Wisconsin - Madison',
    'wit.edu': 'Wentworth Institute of Technology',
    'wits.ac.za': 'University of Witwatersrand',
    'wittenberg.edu': 'Wittenberg University',
    'wiut.uz': 'Westminster International University in Tashkent',
    'wku.edu': 'Western Kentucky University',
    'wku.edu.et': 'Wolkite University',
    'wlac.edu': 'West Los Angeles College',
    'wlc.edu': 'Wisconsin Lutheran College',
    'wlu.ca': 'Wilfrid Laurier University',
    'wlu.edu': 'Washington & Lee University',
    'wlv.ac.uk': 'University of Wolverhampton',
    'wm.edu': 'College of William and Mary',
    'wmich.edu': 'Western Michigan University',
    'wmpenn.edu': 'William Penn College',
    'wne.edu': 'Western New England University',
    'wofford.edu': 'Wofford College',
    'wooster.edu': 'College of Wooster',
    'wpi.edu': 'Worcester Polytechnic Institute',
    'wright.edu': 'Wright State University',
    'wssu.edu': 'Winston-Salem State University',
    'wsu.ac.kr': 'Woosong University',
    'wsu.edu': 'Washington State University',
    'wtamu.edu': 'West Texas A&M University',
    'wu.ac.th': 'Walailak University',
    'wu.edu.et': 'Wollo University',
    'wustl.edu': 'Washington University, Saint Louis',
    'wvu.edu': 'West Virginia University',
    'wwu.edu': 'Western Washington University',
    'xaut.edu.cn': "Xi'an University of Technology",
    'xavier.edu': 'Xavier University',
    'xhu.edu.cn': 'Xihua University',
    'xidian.edu.cn': "Xi'an University of Electronic Science and Technology",
    'xjtlu.edu.cn': "Xi'an Jiaotong-Liverpool University",
    'xjtu.edu.cn': "Xi'an Jiaotong University",
    'xmu.edu.cn': 'Xiamen University',
    'xtu.edu.cn': 'Xiangtan University',
    'xula.edu': 'Xavier University of Louisiana',
    'yale-nus.edu.sg': 'yale-NUS',
    'yale.edu': 'Yale University',
    'yamagata-u.ac.jp': 'Yamagata University',
    'yamanashi.ac.jp': 'Yamanashi University',
    'ybu.edu.tr': 'Yildirim Beyazit University',
    'yc.yccd.edu': 'Yuba College',
    'ycp.edu': 'York College of Pennsylvania',
    'yeditepe.edu.tr': 'Yeditepe University',
    'yildiz.edu.tr': 'Yildiz Technical University',
    'ym.edu.tw': 'National Yang Ming Medical College',
    'ynau.edu.cn': 'Yunnan Agriculture University',
    'ynu.edu.cn': 'Yunnan University',
    'yonsei.ac.kr': 'Yonsei University',
    'york.ac.uk': 'University of York',
    'yorku.ca': 'York University',
    'ysu.am': 'Yerevan State University',
    'ysu.edu': 'Youngstown State University',
    'ysu.edu.cn': 'Yan Shan University',
    'ytu.edu.cn': 'Yantai University',
    'yu.edu': 'Yeshiva University',
    'yu.edu.jo': 'Al Yarmouk University College',
    'yzu.edu.tw': 'Yuan Ze University',
    'zcu.cz': 'University of West Bohemia',
    'zhaw.ch': 'ZHAW - Zürcher Hochschule für Angewandte Wissenschaften',
    'zjgsu.edu.cn': 'Zhejiang Gongshang University',
    'zjnu.edu.cn': 'Zhejiang Normal University',
    'zju.edu.cn': 'Zhejiang University',
    'zjut.edu.cn': 'Zhejiang University of Technology',
    'zntu.edu.ua': 'Zaporizhzhe National Technical University',
    'znu.ac.ir': 'Zanjan University',
    'znu.edu.ua': 'Zaporizhzhe National University',
    'zstu.edu.cn': 'Zhejiang Sci-Tech University',
    'zu.edu.eg': 'Zagazig University',
    'zut.edu.pl': 'Zachodniopomorska School of Science and Engineering'
}
